#### libraries ####
library (nlme)
library (car)
library (emmeans)
library (dunn.test)
library (multcomp)
library (MuMIn)
library (lme4)
library (openxlsx)

# plotting models
library (dplyr)
library (sjPlot)
library (sjmisc)
library (snakecase)
library (ggplot2)
library (ggpubr)
library (ggforce)
library (patchwork)
library (ggbreak)
library (gridExtra)
library (ggridges)

#### summary function ####
data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}

#### Violin split plot function ####
GeomSplitViolin <- ggproto("GeomSplitViolin", GeomViolin, 
                           draw_group = function(self, data, ..., draw_quantiles = NULL) {
                             data <- transform(data, xminv = x - violinwidth * (x - xmin), xmaxv = x + violinwidth * (xmax - x))
                             grp <- data[1, "group"]
                             newdata <- plyr::arrange(transform(data, x = if (grp %% 2 == 1) xminv else xmaxv), if (grp %% 2 == 1) y else -y)
                             newdata <- rbind(newdata[1, ], newdata, newdata[nrow(newdata), ], newdata[1, ])
                             newdata[c(1, nrow(newdata) - 1, nrow(newdata)), "x"] <- round(newdata[1, "x"])
                             
                             if (length(draw_quantiles) > 0 & !scales::zero_range(range(data$y))) {
                               stopifnot(all(draw_quantiles >= 0), all(draw_quantiles <=
                                                                         1))
                               quantiles <- ggplot2:::create_quantile_segment_frame(data, draw_quantiles)
                               aesthetics <- data[rep(1, nrow(quantiles)), setdiff(names(data), c("x", "y")), drop = FALSE]
                               aesthetics$alpha <- rep(1, nrow(quantiles))
                               both <- cbind(quantiles, aesthetics)
                               quantile_grob <- GeomPath$draw_panel(both, ...)
                               ggplot2:::ggname("geom_split_violin", grid::grobTree(GeomPolygon$draw_panel(newdata, ...), quantile_grob))
                             }
                             else {
                               ggplot2:::ggname("geom_split_violin", GeomPolygon$draw_panel(newdata, ...))
                             }
                           })

geom_split_violin <- function(mapping = NULL, data = NULL, stat = "ydensity", position = "identity", ..., 
                              draw_quantiles = NULL, trim = TRUE, scale = "area", na.rm = FALSE, 
                              show.legend = NA, inherit.aes = TRUE) {
  layer(data = data, mapping = mapping, stat = stat, geom = GeomSplitViolin, 
        position = position, show.legend = show.legend, inherit.aes = inherit.aes, 
        params = list(trim = trim, scale = scale, draw_quantiles = draw_quantiles, na.rm = na.rm, ...))
}

#### Plot themes ####
PlotTheme <- theme (panel.background = element_rect (fill = "white", colour = "white")) + # removes background and border
  theme (axis.line = element_line (colour = "black")) + # adds axis colour
  theme (plot.title = element_text (hjust = 0.5)) + # center the title
  theme (plot.title = element_text (size = 18)) + # changes text size of title
  theme (plot.title = element_text (margin = margin (t = , r = 0, b = 0, l = 0))) + # changes distance of title to graph
  theme (axis.text = element_text (size = 20)) + # changes text size of the axis
  theme (axis.title = element_text (size = 20)) + # changes text size and style of the axis
  theme (plot.subtitle = element_text (size = 20, face = "bold")) + # changes text size and style of the axis
  theme (axis.title.y = element_text (margin = margin (t = 0, r = 10, b = 0, l = 0))) + # changes distance of y axis
  theme (axis.title.x = element_text (margin = margin (t = 10, r = 0, b = 0, l = 0))) + # changes distance of x axis
  #theme (plot.tag = element_text (size = 25, face = "bold", margin = margin (t = 5, r = 0, b = 0, l = 10))) + # changes text size, style, and position of the tag
  theme (legend.title = element_text (size = 18, face = "bold")) +
  theme (legend.text = element_text (size = 18)) +
  theme (legend.key.size = unit (1, "cm")) +
  #theme (strip.text = element_text (size = 15)) +
  theme (legend.key = element_rect (colour = NA, fill = NA)) +
  theme (legend.position = "top")

#### ENVIRONMENTAL CONDITIONS ####
# Fjelldal design ####
Fjelldal.design <- read.xlsx ("Fraser et al.xlsx", sheet = 1)
Fjelldal.design$Date <- as.Date(Fjelldal.design$Date, origin="1899-12-30")
str (Fjelldal.design)

# figure
Fig.2A <- ggplot (Fjelldal.design, aes (x = Date, y = Temperature)) + PlotTheme +
  geom_line (aes (y = Temperature), color = "grey") +
  geom_point (aes (y = Temperature, color = Temperature)) +
  scale_colour_gradient2(low = "blue",
                         midpoint = 8,
                         mid = "purple",
                         high = "red",
                         space = "Lab",
                         na.value = "grey50",
                         guide = "colourbar",
                         aesthetics = "colour",
                         limits = c(0, 16)) +
  geom_line (aes (y = Daylength)) +
  labs (title = "Advanced maturation regime", x = "Date", y = "Temperature (\u00b0C) / Daylength (hrs)") +
  theme (plot.title = element_text (margin = margin (t = , r = 0, b = 10, l = 0))) + 
  scale_x_date (date_breaks = "2 month", date_labels = "%b %Y", limits = as.Date(c("2017-03-01", "2018-12-01"))) +
  scale_y_continuous (limits = c(0, 24), breaks = c(0, 4, 8, 12, 16, 20, 24)) +
  theme (axis.text.x = element_text(angle = 45, hjust =1, size = 15)) +
  geom_segment (aes(x = as.Date(c("2018-03-6")), y = 2, xend = as.Date(c("2018-03-06")), yend = 0), arrow = arrow(length = unit(0.25, "cm"))) 
Fig.2A

# Seawater design ####
SW.design <- read.xlsx ("Fraser et al.xlsx", sheet = 3)
SW.design$Date <- as.Date(SW.design$Date, origin="1899-12-30")
str (SW.design)

# figure
Fig.2B <- ggplot (SW.design, aes (x = Date, y = Temperature)) + PlotTheme +
  geom_line (aes (y = Temperature), color = "grey") +
  geom_point (aes (y = Temperature, color = Temperature)) +
  scale_colour_gradient2(low = "blue",
                         midpoint = 8,
                         mid = "purple",
                         high = "red",
                         space = "Lab",
                         na.value = "grey50",
                         guide = "colourbar",
                         aesthetics = "colour",
                         limits = c(0, 16)) +
  geom_line (aes (y = Daylength)) +
  labs (title = "Sea transfer regime", x = "Date", y = "Temperature (\u00b0C) / Daylength (hrs)") +
  theme (plot.title = element_text (margin = margin (t = , r = 0, b = 10, l = 0))) + 
  scale_x_date (date_breaks = "2 month", date_labels = "%b %Y", limits = as.Date(c("2017-03-01", "2018-12-01"))) +
  scale_y_continuous (limits = c(0, 24), breaks = c(0, 4, 8, 12, 16, 20, 24)) +
  theme (axis.text.x = element_text(angle = 45, hjust =1, size = 15)) +
  geom_vline (xintercept = as.numeric(as.Date("2018-05-01")), size = .5, linetype = "dashed") +
  geom_segment (aes(x = as.Date(c("2018-11-19")), y = 2, xend = as.Date(c("2018-11-19")), yend = 0), arrow = arrow(length = unit(0.25, "cm"))) 
Fig.2B

# Freshwater design ####
FW.design <- read.xlsx ("Fraser et al.xlsx", sheet = 2)
FW.design$Date <- as.Date(FW.design$Date, origin="1899-12-30")
str (FW.design)

# figure
Fig.2C <- ggplot (FW.design, aes (x = Date, y = Temperature)) + PlotTheme +
  geom_line (aes (y = Temperature), color = "grey") +
  geom_point (aes (y = Temperature, color = Temperature)) +
  scale_colour_gradient2(low = "blue",
                        midpoint = 8,
                        mid = "purple",
                        high = "red",
                        space = "Lab",
                        na.value = "grey50",
                        guide = "colourbar",
                        aesthetics = "colour",
                        limits = c(0, 16)) +
  geom_line (aes (y = Daylength)) +
  labs (title = "Extended freshwater regime", x = "Date", y = "Temperature (\u00b0C) / Daylength (hrs)") +
  theme (plot.title = element_text (margin = margin (t = , r = 0, b = 10, l = 0))) + 
  scale_x_date (date_breaks = "2 month", date_labels = "%b %Y", limits = as.Date(c("2017-03-01", "2018-12-01"))) +
  scale_y_continuous (limits = c(0, 24), breaks = c(0, 4, 8, 12, 16, 20, 24)) +
  theme (axis.text.x = element_text(angle = 45, hjust =1, size = 15)) +
  geom_segment (aes(x = as.Date(c("2018-10-23")), y = 2, xend = as.Date(c("2018-10-23")), yend = 0), arrow = arrow(length = unit(0.25, "cm"))) 
Fig.2C

# figures
Fig.2A.edt <- Fig.2A +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.text.y = element_text(size = 15)) +
  theme (legend.text = element_text (size = 10)) +
  theme (legend.title = element_text (size = 15, vjust = 1.5))

Fig.2B.edt <- Fig.2B +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.text.y = element_text(size = 15)) +
  theme (legend.text = element_text (size = 10)) +
  theme (legend.title = element_text (size = 15, vjust = 1.5)) 

Fig.2C.edt <- Fig.2C +
  theme (axis.title.y = element_blank ()) +
  theme (axis.text.y = element_text(size = 15)) +
  theme (legend.text = element_text (size = 10)) +
  theme (legend.title = element_text (size = 15, vjust = 1.5)) 

#### Figure 2 ####
Fig.2A.edt / Fig.2B.edt / Fig.2C.edt +
  plot_annotation (tag_levels = "A") +
  plot_layout (guides = "collect") & theme (legend.position = "right", plot.tag = element_text(size = 18)) 

## options for including merged axis
# grab y axis
ylab <- Fig.2A.edt$labels$y
Fig.2B.edt$labels$y <- Fig2C.edt$labels$y <- " "

# stick it on using a grob
grid::grid.draw(grid::textGrob(ylab, x = 0.02, rot = 90, gp = gpar(col = "black", fontsize = 20)))

# gridExtra (library(gridExtra))
grid.arrange (patchworkGrob(Fig.2A.edt / Fig.2B.edt / Fig.2C.edt +
                              plot_annotation(tag_levels = "A") +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "right")),
              left = text_grob ("Temperature (\u00b0C) / Daylength (hrs)", size = 18, rot = 90, face = "bold"))

# MATURATION DATAFRAME ####
Fjelldal.et.al.data <- read.xlsx ("Fraser et al.xlsx", sheet = 4)
Fjelldal.et.al.data$Experiment <- c("AM")
Fjelldal.et.al.data$Date <- as.Date(Fjelldal.et.al.data$Date, origin="1899-12-30")

Freshwater.data <- read.xlsx ("Fraser et al.xlsx", sheet = 5)
Freshwater.data$Experiment <- c("EF")
Freshwater.data$Date <- as.Date(Freshwater.data$Date, origin="1899-12-30")

Seawater.data <- read.xlsx ("Fraser et al.xlsx", sheet = 6)
Seawater.data$Experiment <- c("ST")
Seawater.data$Date <- as.Date(Seawater.data$Date, origin="1899-12-30")

# combine the maturation datasets
Maturation.data <- rbind (Fjelldal.et.al.data, Freshwater.data, Seawater.data)
levels (Maturation.data$Genotype) <- c(levels(Maturation.data$Genotype), "EE", "EL", "LL") 
Maturation.data$Genotype [Maturation.data$Genotype == "Early/Early"] <- "EE"
Maturation.data$Genotype [Maturation.data$Genotype == "Early/Late"] <- "EL"
Maturation.data$Genotype [Maturation.data$Genotype == "Late/Late"] <- "LL"

# how many females?
Female.data <- subset (Maturation.data, Sex != "")
table (Female.data$Sex)
Percent <- 100 * (95/(95+3797))
Percent

table (Female.data$Experiment, Female.data$Sex)
Percent <- 100 * (15/(15+609))
Percent
Percent <- 100 * (52/(52+1544))
Percent
Percent <- 100 * (28/(28+1644))
Percent

table (Female.data$Family, Female.data$Sex)
Percent <- 100 * (14/(14+662))
Percent # family 2
Percent <- 100 * (6/(6+661))
Percent # family 4
Percent <- 100 * (33/(33+897))
Percent # family 6
Percent <- 100 * (42/(42+850))
Percent # family 8
Percent <- 100 * (0/(0+727))
Percent # family 9

# clean up the dataframe
Maturation.data <- subset (Maturation.data, Genotype != "" & Family != "" & Sex == "Male" & Theoretical != "No")
Maturation.data$Family <- factor (Maturation.data$Family)
Maturation.data$Fish <- factor (Maturation.data$Fish)
Maturation.data$PIT <- factor (Maturation.data$PIT)
Maturation.data$Genotype <- factor (Maturation.data$Genotype)
Maturation.data$Sex <- factor (Maturation.data$Sex)
Maturation.data$Mature <- factor (Maturation.data$Mature)
Maturation.data$Matured <- factor (Maturation.data$Matured)
Maturation.data$Dam <- factor (Maturation.data$Dam)
Maturation.data$Sire <- factor (Maturation.data$Sire)
Maturation.data$Experiment <- factor (Maturation.data$Experiment)
str (Maturation.data)

# population mean weight ####
AM.weight <- subset (Maturation.data, Experiment == "AM" & Date == as.Date("2018-03-06"))
summary (AM.weight$Weight)

ST.weight <- subset (Maturation.data, Experiment == "ST")
summary (ST.weight$Weight)
tapply (ST.weight$Weight, ST.weight$Year, summary)
tapply (ST.weight$Mature, ST.weight$Year, summary)

EF.weight <- subset (Maturation.data, Experiment == "EF")
summary (EF.weight$Weight)

# only 2018
Mat.2018 <- subset (Maturation.data, Date > as.Date("2018-02-02") & Date != as.Date("2018-04-16") & Year == 2018 & Mature != "") 
Mat.2018 <- subset (Mat.2018, Mature != "") # Missing data for 174 in 2018

Mat.2018$EnvGen <- paste (Mat.2018$Experiment, Mat.2018$Genotype)
Mat.2018$MatGen <- paste (Mat.2018$Mature, Mat.2018$Genotype)
Mat.2018$MatEnv <- paste (Mat.2018$Mature, Mat.2018$Experiment)
Mat.2018$Experiment <- factor (Mat.2018$Experiment)
str (Mat.2018)

# summarise data in new dataframe
table (Mat.2018$Mature, Mat.2018$Experiment)

# plot data
plot.1 <- ggplot (Mat.2018, aes (x = Genotype, fill = Mature)) +
  PlotTheme +
  geom_bar (position = "fill") 
plot.1 
plot.1 + facet_grid (. ~ Experiment)
plot.1 + facet_grid (Experiment ~ Family)

# check for tank effects in the freshwater protocol
plot.2 <- ggplot (subset (Mat.2018, Experiment == "EF"), aes (x = Tank, fill = Mature)) +
  PlotTheme +
  geom_bar (position = "fill") +
  theme (axis.text.x = element_text (angle = 45, vjust = 1, hjust = 1))
plot.2 + facet_grid (Family ~ Genotype)

Tank.check <- subset (Mat.2018, Experiment == "EF")

table (Tank.check$Tank, Tank.check$Genotype, Tank.check$Mature)
# Only 4 LL fish in tank M17, none are mature. There are 6 LL fish in tank M16, with 3 mature

# Only those in seawater
plot.3 <- ggplot (Mat.2018, aes (x = Genotype, fill = Mature)) +
  PlotTheme +
  geom_bar (position = "fill") 
plot.3 
plot.3 + facet_grid (. ~ Experiment)
plot.3 + facet_grid (Experiment ~ Family)

#### family 2 raw maturation data between environments in 2018 ####
# dataframe 
Fam.2.2018 <- subset (Mat.2018, Family == 2)

# genotype x environment
table (Fam.2.2018$Genotype, Fam.2.2018$Experiment)

plot.4 <- ggplot (Fam.2.2018, aes (x = reorder(EnvGen, desc(EnvGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white","#00A9E0", "#59C7EB")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 4, y = 1.05, label = "81", size = 5, color = "#636363") + 
  annotate ("text", x = 3, y = 1.05, label = "94", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "39", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "38", size = 5, color = "#636363") + 
  coord_flip ()
plot.4

# environment
table (Fam.2.2018$Experiment)

plot.5 <- ggplot (Fam.2.2018, aes (x = reorder(Experiment, desc(Experiment)), fill = MatEnv, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white", "#74c476", "white")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 2, y = 1.05, label = "175", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "77", size = 5, color = "#636363") + 
  coord_flip ()
plot.5

# genotype
table (Fam.2.2018$Genotype)

plot.6 <- ggplot (Fam.2.2018, aes (x = reorder(Genotype, desc(Genotype)), fill = MatGen, color = Genotype)) +
  scale_fill_manual (values =c ("white", "white", "#00a9e0", "#59c7eb")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  #annotate ("text", x = 2, y = .05, label = "a", size = 5, color = "#636363") + 
  #annotate ("text", x = 1, y = .05, label = "b", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 1.05, label = "120", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "132", size = 5, color = "#636363") + 
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  coord_flip ()
plot.6

#### family 4 raw maturation data between environments in 2018 ####
# dataframe 
Fam.4.2018 <- subset (Mat.2018, Family == 4)

# genotype x environment
table (Fam.4.2018$Genotype, Fam.4.2018$Experiment)

plot.7 <- ggplot (Fam.4.2018, aes (x = reorder(EnvGen, desc(EnvGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white","#59c7eb", "#a6e1f4")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 4, y = 1.05, label = "98", size = 5, color = "#636363") + 
  annotate ("text", x = 3, y = 1.05, label = "76", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "51", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "26", size = 5, color = "#636363") + 
  coord_flip ()
plot.7

# environment
table (Fam.4.2018$Experiment)

plot.8 <- ggplot (Fam.4.2018, aes (x = reorder(Experiment, desc(Experiment)), fill = MatEnv, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white", "#74c476", "#bae4b3")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 2, y = 1.05, label = "174", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "77", size = 5, color = "#636363") + 
  coord_flip ()
plot.8

# genotype
table (Fam.4.2018$Genotype)

plot.9 <- ggplot (Fam.4.2018, aes (x = reorder(Genotype, desc(Genotype)), fill = MatGen, color = Genotype)) +
  scale_fill_manual (values =c ("white", "white","#59c7eb", "#a6e1f4")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  annotate ("text", x = 2, y = 1.05, label = "149", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "102", size = 5, color = "#636363") + 
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  coord_flip ()
plot.9

#### family 6 raw maturation data between environments in 2018 ####
# dataframe 
Fam.6.2018 <- subset (Mat.2018, Family == 6)

# genotype x environment
table (Fam.6.2018$Genotype, Fam.6.2018$Experiment)

plot.10 <- ggplot (Fam.6.2018, aes (x = reorder(EnvGen, desc(EnvGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white","#00a9e0", "#59c7eb")) +
  scale_color_manual (values =c ("black", "black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 6, y = 1.05, label = "121", size = 5, color = "#636363") + 
  annotate ("text", x = 5, y = 1.05, label = "130", size = 5, color = "#636363") + 
  annotate ("text", x = 4, y = 1.05, label = "78", size = 5, color = "#636363") + 
  annotate ("text", x = 3, y = 1.05, label = "93", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "40", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "33", size = 5, color = "#636363") + 
  coord_flip ()
plot.10

# environment
table (Fam.6.2018$Experiment)

plot.11 <- ggplot (Fam.6.2018, aes (x = reorder(Experiment, desc(Experiment)), fill = MatEnv, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white","white", "#238b45", "#74c476", "#bae4b3")) +
  scale_color_manual (values =c ("black", "black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 3, y = 1.05, label = "251", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "171", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "73", size = 5, color = "#636363") + 
  coord_flip ()
plot.11

# genotype
table (Fam.6.2018$Genotype)

plot.12 <- ggplot (Fam.6.2018, aes (x = reorder(Genotype, desc(Genotype)), fill = MatGen, color = Genotype)) +
  scale_fill_manual (values =c ("white", "white", "#00a9e0", "#59c7eb")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  annotate ("text", x = 2, y = 1.05, label = "239", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "256", size = 5, color = "#636363") + 
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  coord_flip ()
plot.12

#### family 8 raw maturation data between environments in 2018 ####
# dataframe 
Fam.8.2018 <- subset (Mat.2018, Family == 8)

# genotype x environment
table (Fam.8.2018$Genotype, Fam.8.2018$Experiment)

plot.13 <- ggplot (Fam.8.2018, aes (x = reorder(EnvGen, desc(EnvGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white","#59c7eb", "#a6e1f4")) +
  scale_color_manual (values =c ("black", "black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 6, y = 1.05, label = "101", size = 5, color = "#636363") + 
  annotate ("text", x = 5, y = 1.05, label = "85", size = 5, color = "#636363") + 
  annotate ("text", x = 4, y = 1.05, label = "77", size = 5, color = "#636363") + 
  annotate ("text", x = 3, y = 1.05, label = "85", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "44", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "39", size = 5, color = "#636363") +
  coord_flip ()
plot.13

# environment
table (Fam.8.2018$Experiment)

plot.14 <- ggplot (Fam.8.2018, aes (x = reorder(Experiment, desc(Experiment)), fill = MatEnv, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white","white", "#238b45", "#74c476", "#bae4b3")) +
  scale_color_manual (values =c ("black", "black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 3, y = 1.05, label = "186", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "162", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "83", size = 5, color = "#636363") + 
  coord_flip ()
plot.14

# genotype
table (Fam.8.2018$Genotype)

plot.15 <- ggplot (Fam.8.2018, aes (x = reorder(Genotype, desc(Genotype)), fill = MatGen, color = Genotype)) +
  scale_fill_manual (values =c ("white", "white","#59c7eb", "#a6e1f4")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  annotate ("text", x = 2, y = 1.05, label = "222", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "209", size = 5, color = "#636363") + 
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  coord_flip ()
plot.15

#### family 9 raw maturation data between environments in 2018 ####
# dataframe 
Fam.9.2018 <- subset (Mat.2018, Family == 9)

# genotype x environment
table (Fam.9.2018$Genotype, Fam.9.2018$Experiment)

plot.16 <- ggplot (Fam.9.2018, aes (x = reorder(EnvGen, desc(EnvGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "#00a9e0")) +
  scale_color_manual (values =c ("black", "black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.y = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  labs (y = "Proportion matured") +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 3, y = 1.05, label = "155", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "89", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "96", size = 5, color = "#636363") + 
  coord_flip ()
plot.16

# environment
table (Fam.9.2018$Experiment)

plot.17 <- ggplot (Fam.9.2018, aes (x = reorder(Experiment, desc(Experiment)), fill = MatEnv, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white","white", "#238b45", "#74c476", "#bae4b3")) +
  scale_color_manual (values =c ("black", "black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.y = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  labs (y = "Proportion matured") +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 3, y = 1.05, label = "155", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "89", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "96", size = 5, color = "#636363") + 
  coord_flip ()
plot.17

# genotype
table (Fam.9.2018$Genotype)

plot.18 <- ggplot (Fam.9.2018, aes (x = reorder(Genotype, desc(Genotype)), fill = MatGen, color = Genotype)) +
  scale_fill_manual (values =c ("white", "#00a9e0")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.y = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  labs (y = "Proportion matured") +
  annotate ("text", x = 1, y = 1.05, label = "340", size = 5, color = "#636363") + 
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  coord_flip ()
plot.18

#### figure - raw environment maturation data ####
Layout.S1 <- "
A
A
B
B
C
C
C
D
D
D
E
E
E
"

plot.19 <- plot.5 / plot.8 / plot.11 / plot.14 / plot.17 +
  plot_layout (guides = "collect", design = Layout.S1) & theme (legend.position = "none") 
plot.19

#### figure - raw vgll3 maturation data ####
Layout.S2 <- "
A
A
B
B
C
C
D
D
E
"
plot.20 <- plot.6 / plot.9 / plot.12 / plot.15 / plot.18  +
  plot_layout (guides = "collect", design = Layout.S2) & theme (legend.position = "none") 
plot.20

#### figure - raw family maturation data ####
table (Mat.2018$Family)

plot.21 <- ggplot (Mat.2018, aes (x = reorder(Family, desc(Family)), fill = Mature, color = Mature)) +
  scale_fill_manual (values =c ("white", "grey")) +
  scale_color_manual (values =c ("black", "black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  theme (axis.text = element_text (size = 15)) +
  labs (y = "Proportion matured", x = "Family") +
  annotate ("text", x = 5, y = 1.05, label = "252", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = 1.05, label = "251", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 1.05, label = "495", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 1.05, label = "431", size = 5, color = "#636363") +
  annotate ("text", x = 1, y = 1.05, label = "340", size = 5, color = "#636363") +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  coord_flip ()
plot.21

#### Figure S1 raw genotype x family x environment maturation data ####
# layout
Layout.S4 <- "
A
A
A
A
B
B
B
B
C
C
C
C
C
C
D
D
D
D
D
D
E
E
E
"

Fig.S1 <- plot.4 / plot.7 / plot.10 / plot.13 / plot.16 +
  plot_layout (guides = "collect", design = Layout.S4) &
  theme (legend.position = "none") 
Fig.S1

# gridExtra
grid.arrange (patchworkGrob(plot.4 / plot.7 / plot.10 / plot.13 / plot.16 +
                              plot_layout (guides = "collect", design = Layout.S4) &
                              theme (legend.position = "none")),
              left = text_grob ("Environment and vgll3 genotype", size = 18, rot = 90, face = "bold"))

#### which environment had the most maturation? ####
M1 <- glmer (Mature ~ Experiment + (1|Family) + (1|Genotype), family = "binomial", data = Mat.2018)
Anova (M1)
r.squaredGLMM (M1) 
lsmeans (M1, pairwise ~ Experiment, type = "response", adjust = "none") 

# figure
env.lsm <- data.frame (lsmeans (M1, revpairwise ~ Experiment, type = "response"))
env.lsm$Mature <- env.lsm$prob * 100 
env.lsm$Upper <- env.lsm$asymp.UCL * 100 
env.lsm$Lower <- env.lsm$asymp.LCL * 100 
env.lsm <- subset (env.lsm, Experiment != ".")
str (env.lsm)

Fig.3a <- ggplot (env.lsm, aes (x = Mature, y = reorder(Experiment, (Mature)), fill = Experiment, color = Experiment)) +
  scale_fill_manual (values = c("#74c476", "#238b45", "#bae4b3")) +
  scale_color_manual (values = c("#74c476", "#238b45", "#bae4b3")) +
  PlotTheme +
  geom_point (size = 7) +
  theme (axis.text = element_text (size = 20)) +
  labs (x = "Maturation (%)", y = "Regime") +
  theme (legend.position = "none") +
  geom_errorbar (aes (xmin = Lower, xmax = Upper), size = 5, width = 0, alpha = .5)
Fig.3a

## p value figure
# standard
marginal = lsmeans (M1, ~ Experiment, type = "response")
plot.22 <- pwpp (marginal, adjust = "none", values = TRUE, plim = c(0,1)) +
  PlotTheme
plot.22

# custom
lsm <- lsmeans (M1, pairwise ~ Experiment, type = "response", adjust = "none") 
pval <- summary(lsm$contrasts)$p.value
pval

lsm.p.env <- data.frame (c("EF", "AM", "EF", "ST", "AM", "ST"), 
                         c(0.1165852, 0.1165852,
                           0.00000000000000000000000000000000000000000000001027563, 0.00000000000000000000000000000000000000000000001027563,
                           0.00000000000000000000000000000000000000000000005554209, 0.00000000000000000000000000000000000000000000005554209),
                         c(90.97, 88.13, 90.97, 5.66, 88.13, 5.66),
                         c("A", "A", "B", "B", "C", "C"),
                         c("A", "A", "B", "B", "A", "A"))

names (lsm.p.env) <- c ("Experiment", "p", "Mature", "Comparison", "Color") 

plot.23 <- ggplot (lsm.p.env, aes (x = p, y = reorder(Experiment, (Mature)), group = Comparison)) +
  PlotTheme +
  geom_point () +
  geom_line () +
  labs (x = "p-value", y = "Experiment") +
  coord_trans(x = "sqrt") +
  scale_x_continuous (breaks = c(0.001, 0.01, 0.05, 0.1, 0.5, 1.0), lim = c(0,1))
plot.23

plot.24 <- ggplot (lsm.p.env, aes (x = p, y = reorder(Experiment, (Mature)), group = Comparison)) +
  PlotTheme +
  geom_point () +
  geom_line () +
  labs (x = "p-value", y = "Experiment") +
  scale_x_log10(breaks = trans_breaks("log10", function(x) 10^x), labels = trans_format("log10", math_format(10^.x))) +
  geom_vline (xintercept = 0.05)
plot.24

library (scales)
S_sqrt <- function(x){sign(x)*sqrt(abs(x))}
IS_sqrt <- function(x){x^2*sign(x)}
S_sqrt_trans <- function() trans_new("S_sqrt",S_sqrt,IS_sqrt)

fig.3b <- ggplot (lsm.p.env, aes (x = p, y = reorder(Experiment, (Mature)), group = Comparison, color = Color)) +
  PlotTheme +
  geom_point () +
  geom_line () +
  labs (x = "p-value", y = "Experiment") +
  scale_x_continuous(trans ="S_sqrt", breaks = c(0, 0.01, 0.05, 0.1, 0.2, 1.0), lim = c(0,.2)) +
  scale_color_manual (values = c("red", "black")) +
  theme (legend.position = "none") +
  theme (axis.text.x = element_text (angle = 45, vjust = 1, hjust = 1))
fig.3b

#### which genotype had the most maturation? ####
M2 <- glmer (Mature ~ Genotype + (1|Family) + (1|Experiment), family = "binomial", data = Mat.2018)
Anova (M2)
r.squaredGLMM (M2) 
lsmeans (M2, pairwise ~ Genotype, type = "response", adjust = "none")

# figure 3b
geno.lsm <- data.frame (lsmeans (M2, revpairwise ~ Genotype, type = "response"))
geno.lsm$Mature <- geno.lsm$prob * 100 
geno.lsm$Upper <- geno.lsm$asymp.UCL * 100 
geno.lsm$Lower <- geno.lsm$asymp.LCL * 100 
geno.lsm <- subset (geno.lsm, Genotype != ".")
str (geno.lsm)

Fig.3c <- ggplot (geno.lsm, aes (x = Mature, y = reorder(Genotype, desc(Genotype)), fill = Genotype, color = Genotype)) +
  scale_fill_manual (values =c ("#00A9E0", "#59C7EB", "#A6E1F4")) +
  scale_color_manual (values =c ("#00A9E0", "#59C7EB", "#A6E1F4")) +
  PlotTheme +
  geom_point (size = 7) +
  theme (axis.text = element_text (size = 20)) +
  labs (x = "Maturation (%)", y = "Genotype") +
  theme (legend.position = "none") +
  geom_errorbar (aes (xmin = Lower, xmax = Upper), size = 5, width = 0, alpha = .5)
Fig.3c

# p value figure
lsm <- lsmeans (M2, pairwise ~ Genotype, type = "response", adjust = "none") 
pval <- summary(lsm$contrasts)$p.value
pval

lsm.p.geno <- data.frame (c("EE", "EL", "EE", "LL", "EL", "LL"), 
                         c(0.001863043, 0.001863043,
                           0.00000000000168792, 0.00000000000168792,
                           0.000000000000002968252, 0.000000000000002968252),
                         c(82.7, 67.2, 82.7, 31.1, 67.2, 31.1),
                         c("A", "A", "B", "B", "C", "C"),
                         c("A", "A", "B", "B", "A", "A"))
names (lsm.p.geno) <- c ("Genotype", "p", "Mature", "Comparison", "Color") 

fig.3d <- ggplot (lsm.p.geno, aes (x = p, y = reorder(Genotype, desc(Genotype)), group = Comparison, color = Color)) +
  PlotTheme +
  geom_point () +
  geom_line () +
  labs (x = "p-value", y = "Genotype") +
  scale_x_continuous(trans ="S_sqrt", breaks = c(0, 0.01, 0.05, 0.1, 0.2, 1.0), lim = c(0,.2)) +
  scale_color_manual (values = c("red", "black")) +
  theme (legend.position = "none") +
  theme (axis.text.x = element_text (angle = 45, vjust = 1, hjust = 1))
fig.3d

#### which family had the most maturation? ####
M3 <- glmer (Mature ~ Family + (1|Genotype) + (1|Experiment), family = "binomial", data = Mat.2018)
Anova (M3)
r.squaredGLMM (M3) 
lsmeans (M3, pairwise ~ Family, type = "response", adjust = "none") 

# figure 3c
fam.lsm <- data.frame (lsmeans (M3, revpairwise ~ Family, type = "response"))
fam.lsm$Mature <- fam.lsm$prob * 100 
fam.lsm$Upper <- fam.lsm$asymp.UCL * 100 
fam.lsm$Lower <- fam.lsm$asymp.LCL * 100 
fam.lsm <- subset (fam.lsm, Family != ".")
str (geno.lsm)

Fig.3e <- ggplot (fam.lsm, aes (x = Mature, y = reorder(Family, (Mature)), fill = Family, color = Family)) +
  scale_fill_manual (values =c ("#EC7014", "#FEC44F",  "#CC4C02", "#FB9A29","#993404")) +
  scale_color_manual (values =c ("#EC7014", "#FEC44F",  "#CC4C02", "#FB9A29","#993404")) +
  PlotTheme +
  geom_point (size = 7) +
  theme (axis.text = element_text (size = 20)) +
  labs (x = "Maturation (%)", y = "Family") +
  theme (legend.position = "none") +
  geom_errorbar (aes (xmin = Lower, xmax = Upper), size = 5, width = 0, alpha = .5)
Fig.3e

# p value figure
lsm <- lsmeans (M3, pairwise ~ Family, type = "response", adjust = "none") 
pval <- summary(lsm$contrasts)$p.value
pval

lsm.p.fam <- data.frame (c("2","4","2","6","2","8","2","9","4","6","4","8","4","9","6","8","8","9","6","9"), 
                          c(0.0001707626, 0.0001707626,
                            0.01874249, 0.01874249,
                            0.1080615, 0.1080615,
                            0.00000000000000000000002380209, 0.00000000000000000000002380209,
                            0.000000001402585, 0.000000001402585,
                            0.007331564, 0.007331564,
                            0.00000000000000000000000000006831535, 0.00000000000000000000000000006831535,
                            0.00001311749, 0.00001311749,
                            0.000000000000000000000001699821, 0.000000000000000000000001699821,
                            0.0000000000000000002246850, 0.0000000000000000002246850),
                          c(41.8, 19.8, 41.8, 57.6, 41.8, 31.1, 41.8, 99.2, 19.8, 57.6, 19.8, 31.1, 19.8, 99.2, 57.6, 31.1, 31.1, 99.2, 57.6, 99.2),
                          c("A", "A", "B", "B", "C", "C", "D", "D", "E", "E", "F", "F", "G", "G", "H", "H", "I", "I", "J", "J"),
                          c("A", "A", "A", "A", "A", "A", "B", "B", "B", "B", "A", "A", "A", "A", "A", "A", "B", "B", "A", "A"))
names (lsm.p.fam) <- c ("Family", "p", "Mature", "Comparison", "Color") 

fig.3f <- ggplot (lsm.p.fam, aes (x = p, y = reorder(Family, (Mature)), group = Comparison, color = Color)) +
  PlotTheme +
  geom_point () +
  geom_line () +
  labs (x = "p-value", y = "Family") +
  scale_x_continuous(trans ="S_sqrt", breaks = c(0, 0.01, 0.05, 0.1, 0.2, 1.0), lim = c(0, 0.2)) +
  scale_color_manual (values = c("red", "black")) +
  theme (legend.position = "none") +
  theme (axis.text.x = element_text (angle = 45, vjust = 1, hjust = 1))
fig.3f

#### Figure 3 edits ####
Fig.3a.edit <- Fig.3a +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.text.x = element_blank ())

Fig.3c.edit <- Fig.3c +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.text.x = element_blank ())

Fig.3e.edit <- Fig.3e +
  theme (axis.text = element_text (size = 15))

fig.3b.edit <- fig.3b +
  theme (axis.text = element_text (size = 15),
         axis.title.y = element_blank (),
         axis.title.x = element_blank (),
         axis.text.x = element_blank (),
         axis.text.y = element_blank ())

fig.3d.edit <- fig.3d +
  theme (axis.text = element_text (size = 15),
         axis.title.y = element_blank (),
         axis.title.x = element_blank (),
         axis.text.x = element_blank (),
         axis.text.y = element_blank ())

fig.3f.edit <- fig.3f +
  theme (axis.text = element_text (size = 15),
         axis.title.y = element_blank (),
         axis.text.y = element_blank ())


#### Figure 3 ####
Fig.3 <- Fig.3a.edit + fig.3b.edit + Fig.3c.edit + fig.3d.edit + Fig.3e.edit + fig.3f.edit +
  plot_annotation (tag_levels = "A") +
  plot_layout (widths = c(2, 1))
Fig.3

#### does family interact with the environment? ####
M4 <- glmer (Mature ~ Family * Experiment + (1|Genotype), family = "binomial", data = Mat.2018)
Anova (M4)
r.squaredGLMM (M4) 
lsmeans (M4, pairwise ~ Family | Experiment , type = "response", adjust = "none") 

# new dataframe
fam.env.lsm <- data.frame (c("EF", "EF", "EF", "AM", "AM", "AM", "AM", "AM", "ST", "ST", "ST", "ST", "ST"), 
                            c(6, 8, 9, 2, 4, 6, 8, 9, 2, 4, 6, 8, 9),
                            c(86.309, 78.668, 97.872, 80.131, 51.197, 96.353, 66.417, 92.844, 0, 12.710, 0.572, 0, 84.420),
                            c(63.6337, 51.0540, 81.7179, 52.7936, 22.9483, 84.7312, 35.8552, 66.1236, 0, 3.3766, 0.0549, 0, 53.0826),
                            c(95.78, 92.88, 99.79, 93.57, 78.7, 99.21, 87.50, 98.85, 13.26, 37.76, 5.69, 0, 96.29))
names (fam.env.lsm) <- c ("Experiment", "Family", "Mature", "Lower", "Upper") # create a blank df for weeks 4 and 5
fam.env.lsm$Family <- factor (fam.env.lsm$Family)
str (fam.env.lsm)

#### Figure 4 ####
Fig.4 <- ggplot (fam.env.lsm, aes (x = reorder (Experiment, desc(Mature)), y = Mature, group = Family), fill = Family, color = Family) +
  scale_fill_manual (values =c ("#EC7014", "#FEC44F",  "#CC4C02", "#FB9A29","#993404")) +
  scale_color_manual (values =c ("#EC7014", "#FEC44F",  "#CC4C02", "#FB9A29","#993404")) +
  PlotTheme +
  geom_point (aes (color = Family), size = 3, position = position_dodge (.2)) +
  geom_line (aes (linetype = Family, color = Family), position = position_dodge (.2), size = .5) +
  theme (axis.text = element_text (size = 20)) +
  theme (legend.position = "right") +
  labs (x = "Regime", y = "Maturation (%)") +
  geom_errorbar (aes (ymin = Lower, ymax = Upper, color = Family), position = position_dodge (.2), width = .1, size = 1, alpha = .5) 
Fig.4  

#### maturation data within family 2 #####
Mat.2018.F2 <- subset (Mat.2018, Family == 2)
Fam.2.jack <- subset (Mat.2018.F2, Experiment == "AM")

# environment
M5 <- glmer (Mature ~ Experiment + (1|Genotype), family = "binomial", data = Mat.2018.F2)
Anova (M5)
r.squaredGLMM (M5)
lsmeans (M5, pairwise ~ Experiment, type = "response", adjust = "none") 

# genotype
M6 <- glm (Mature ~ Genotype, family = "binomial", data = Mat.2018.F2)
Anova (M6)
r.squaredGLMM (M6)
lsmeans (M6, pairwise ~ Genotype, type = "response", adjust = "none") 

M7 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.2.jack)
Anova (M7)
r.squaredGLMM (M7) 
lsmeans (M7, pairwise ~ Genotype, type = "response", adjust = "none") 

#### maturation data within family 4 #####
Mat.2018.F4 <- subset (Mat.2018, Family == 4)

# environment
M8 <- glmer (Mature ~ Experiment + (1|Genotype), family = "binomial", data = Mat.2018.F4)
Anova (M8)
r.squaredGLMM (M8) 
lsmeans (M8, pairwise ~ Experiment, type = "response", adjust = "none") 

# genotype
M9 <- glmer (Mature ~ Genotype + (1|Experiment), family = "binomial", data = Mat.2018.F4)
Anova (M9)
r.squaredGLMM (M9) 
lsmeans (M9, pairwise ~ Genotype, type = "response", adjust = "none") 

#### maturation data within family 6 #####
Mat.2018.F6 <- subset (Mat.2018, Family == 6)

# environment
M10 <- glmer (Mature ~ Experiment + (1|Genotype), family = "binomial", data = Mat.2018.F6)
Anova (M10)
r.squaredGLMM (M10)
lsmeans (M10, pairwise ~ Experiment, type = "response", adjust = "none") 

table (Mat.2018.F6$Mature, Mat.2018.F6$Experiment, Mat.2018.F6$Genotype)

# genotype
M11 <- glmer (Mature ~ Genotype + (1|Experiment), family = "binomial", data = Mat.2018.F6)
Anova (M11) 
r.squaredGLMM (M11)
lsmeans (M11, pairwise ~ Genotype, type = "response", adjust = "none") 

#### maturation data within family 8 #####
Mat.2018.F8 <- subset (Mat.2018, Family == 8)
Fam.8.no.SW <- subset (Mat.2018.F8, Experiment != "ST")

# environment
M12 <- glmer (Mature ~ Experiment + (1|Genotype), family = "binomial", data = Mat.2018.F8)
Anova (M12)
r.squaredGLMM (M12)
lsmeans (M12, pairwise ~ Experiment, type = "response", adjust = "none") 

# environment without the seawater data
M13 <- glmer (Mature ~ Experiment + (1|Genotype), family = "binomial", data = Fam.8.no.SW)
Anova (M13)
r.squaredGLMM (M13)
lsmeans (M13, pairwise ~ Experiment, type = "response", adjust = "none") 

# genotype
M14 <- glmer (Mature ~ Genotype + (1|Experiment), family = "binomial", data = Mat.2018.F8)
Anova (M14)
r.squaredGLMM (M14)
lsmeans (M14, pairwise ~ Genotype, type = "response", adjust = "none") 

# genotype without the seawater data
M15 <- glmer (Mature ~ Genotype + (1|Experiment), family = "binomial", data = Fam.8.no.SW)
Anova (M15)
r.squaredGLMM (M15)
lsmeans (M15, pairwise ~ Genotype, type = "response", adjust = "none") 

#### maturation data within family 9 #####
Fam.9 <- subset (Mat.2018, Family == 9)

# environment
M16 <- glm (Mature ~ Experiment, family = "binomial", data = Fam.9)
Anova (M16)
r.squaredGLMM (M16)
lsmeans (M16, pairwise ~ Experiment, type = "response", adjust = "none") 

#### Long seawater study ####
SW.Mat <- subset (Maturation.data, Experiment == "ST" & Mature != "" & Date != "2018-04-16") 
SW.Mat$YearGen <- paste (SW.Mat$Year, SW.Mat$Genotype)
SW.Mat$MatGen <- paste (SW.Mat$Mature, SW.Mat$Genotype)

plot.25 <- ggplot (SW.Mat, aes (x = Genotype, fill = Mature)) +
  PlotTheme +
  geom_bar (position = "fill") 
plot.25 
plot.25 + facet_grid (Year ~ Family)

# family 2
Fam.2.sea <- subset (SW.Mat, Family == 2)
table (Fam.2.sea$Genotype, Fam.2.sea$Year)

plot.26 <- ggplot (Fam.2.sea, aes (x = reorder(YearGen, desc(YearGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white", "#00a9e0", "#59c7eb")) +
  scale_color_manual (values =c ("black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 6, y = 1.05, label = "39", size = 5, color = "#636363") + 
  annotate ("text", x = 5, y = 1.05, label = "38", size = 5, color = "#636363") + 
  annotate ("text", x = 4, y = 1.05, label = "39", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 1.05, label = "38", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "24", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "34", size = 5, color = "#636363") +
  coord_flip ()
plot.26

# family 4
Fam.4.sea <- subset (SW.Mat, Family == 4)
table (Fam.4.sea$Genotype, Fam.4.sea$Year)

plot.27 <- ggplot (Fam.4.sea, aes (x = reorder(YearGen, desc(YearGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white", "#59c7eb", "#a6e1f4")) +
  scale_color_manual (values =c ("black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 6, y = 1.05, label = "51", size = 5, color = "#636363") + 
  annotate ("text", x = 5, y = 1.05, label = "26", size = 5, color = "#636363") + 
  annotate ("text", x = 4, y = 1.05, label = "46", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 1.05, label = "24", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "43", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "24", size = 5, color = "#636363") +
  coord_flip ()
plot.27

# family 6
Fam.6.sea <- subset (SW.Mat, Family == 6)
table (Fam.6.sea$Genotype, Fam.6.sea$Year)

plot.28 <- ggplot (Fam.6.sea, aes (x = reorder(YearGen, desc(YearGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white", "#00a9e0", "#59c7eb")) +
  scale_color_manual (values =c ("black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 6, y = 1.05, label = "40", size = 5, color = "#636363") + 
  annotate ("text", x = 5, y = 1.05, label = "33", size = 5, color = "#636363") + 
  annotate ("text", x = 4, y = 1.05, label = "40", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 1.05, label = "32", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "31", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "31", size = 5, color = "#636363") +
  coord_flip ()
plot.28

# family 8
Fam.8.sea <- subset (SW.Mat, Family == 8)
table (Fam.8.sea$Genotype, Fam.8.sea$Year)

plot.29 <- ggplot (Fam.8.sea, aes (x = reorder(YearGen, desc(YearGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "white", "#59c7eb", "#a6e1f4")) +
  scale_color_manual (values =c ("black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.x = element_blank (),
         strip.text.x = element_blank (),
         axis.text = element_text (size = 15)) +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 6, y = 1.05, label = "44", size = 5, color = "#636363") + 
  annotate ("text", x = 5, y = 1.05, label = "39", size = 5, color = "#636363") + 
  annotate ("text", x = 4, y = 1.05, label = "44", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 1.05, label = "39", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 1.05, label = "43", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "39", size = 5, color = "#636363") +
  coord_flip ()
plot.29

# family 9
Fam.9.sea <- subset (SW.Mat, Family == 9)
table (Fam.9.sea$Genotype, Fam.9.sea$Year)

plot.30 <- ggplot (Fam.9.sea, aes (x = reorder(YearGen, desc(YearGen)), fill = MatGen, color = Experiment)) +
  scale_fill_manual (values =c ("white", "#00a9e0")) +
  scale_color_manual (values =c ("black")) +
  PlotTheme +
  geom_bar (position = "fill", width = 0.8, size = .5) +
  facet_grid (Family ~ .) +
  theme (axis.title.y = element_blank (),
         axis.text = element_text (size = 15)) +
  labs (y = "Proportion matured") +
  scale_y_continuous (breaks = c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0)) +
  annotate ("text", x = 2, y = 1.05, label = "96", size = 5, color = "#636363") + 
  annotate ("text", x = 1, y = 1.05, label = "5", size = 5, color = "#636363") +
  coord_flip ()
plot.30

#### Figure S2 (using gridextra) ####
Layout.S2 <- "
A
A
A
B
B
B
C
C
C
D
D
D
E
"

grid.arrange (patchworkGrob(plot.26 / plot.27 / plot.28 / plot.29 / plot.30 +
                              plot_layout (guides = "collect", design = Layout.S2) &
                              theme (legend.position = "none")),
              left = text_grob ("Year and vgll3 genotype", size = 18, rot = 90, face = "bold"))

#### family 2 - seawater study ####
# 2019
Fam.2.sea.2019 <- subset (Fam.2.sea, Year == 2019)

M17 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.2.sea.2019)
Anova (M17)
r.squaredGLMM (M17)
lsmeans (M17, pairwise ~ Genotype, type = "response", adjust = "none") 

# 2020
Fam.2.sea.2020 <- subset (Fam.2.sea, Year == 2020)

M18 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.2.sea.2020)
Anova (M18) 
r.squaredGLMM (M18)
lsmeans (M18, pairwise ~ Genotype, type = "response", adjust = "none") 

#### family 4 - seawater study ####
# 2019
Fam.4.sea.2019 <- subset (Fam.4.sea, Year == 2019)

M19 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.4.sea.2019)
Anova (M19)
r.squaredGLMM (M19)
lsmeans (M19, pairwise ~ Genotype, type = "response", adjust = "none") 

# 2020
Fam.4.sea.2020 <- subset (Fam.4.sea, Year == 2020)

M20 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.4.sea.2020)
Anova (M20)
r.squaredGLMM (M20)
lsmeans (M20, pairwise ~ Genotype, type = "response", adjust = "none") 

#### family 6 - seawater study ####
# 2019
Fam.6.sea.2019 <- subset (Fam.6.sea, Year == 2019)

M21 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.6.sea.2019)
Anova (M21) 
r.squaredGLMM (M21)
lsmeans (M21, pairwise ~ Genotype, type = "response", adjust = "none") 

# 2020
Fam.6.sea.2020 <- subset (Fam.6.sea, Year == 2020)

M22 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.6.sea.2020)
Anova (M22) 
r.squaredGLMM (M22)
lsmeans (M22, pairwise ~ Genotype, type = "response", adjust = "none") 

#### family 8 - seawater study ####
# 2019
Fam.8.sea.2019 <- subset (Fam.8.sea, Year == 2019)

M23 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.8.sea.2019)
Anova (M23)
r.squaredGLMM (M23)
lsmeans (M23, pairwise ~ Genotype, type = "response", adjust = "none") 

# 2020
Fam.8.sea.2020 <- subset (Fam.8.sea, Year == 2020)

M24 <- glm (Mature ~ Genotype, family = "binomial", data = Fam.8.sea.2020)
Anova (M24)
r.squaredGLMM (M24)
lsmeans (M24, pairwise ~ Genotype, type = "response", adjust = "none") 

#### Probability of delaying maturation ####
Seawater.data.v2 <- read.xlsx ("Fraser et al.xlsx", sheet = 7)
levels (Seawater.data.v2$Genotype) <- c(levels(Seawater.data.v2$Genotype), "EE", "EL", "LL") 
Seawater.data.v2$Genotype [Seawater.data.v2$Genotype == "Early/Early"] <- "EE"
Seawater.data.v2$Genotype [Seawater.data.v2$Genotype == "Early/Late"] <- "EL"
Seawater.data.v2$Genotype [Seawater.data.v2$Genotype == "Late/Late"] <- "LL"

## 0SW to 1SW
SW1.SW2.data <- subset (Seawater.data.v2, SW1.SW2 != "")
SW1.SW2.data$SW1.SW2 <- factor (SW1.SW2.data$SW1.SW2)
str (SW1.SW2.data)

plot.31 <- ggplot (SW1.SW2.data, aes (x = Genotype, fill = SW1.SW2)) +
  PlotTheme +
  geom_bar (position = "fill") 
plot.31 
plot.31 + facet_grid (. ~ Family)

# general
M25 <- glm (SW1.SW2 ~ Genotype, family = "binomial", data = SW1.SW2.data)
Anova (M25) 

# family 4
Fam.4.SW1.SW2 <- subset (SW1.SW2.data, Family == 4)

M26 <- glm (SW1.SW2 ~ Genotype, family = "binomial", data = Fam.4.SW1.SW2)
Anova (M26)
r.squaredGLMM (M26)
lsmeans (M26, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.32 <- plot_model (M26, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.32 

# family 6
Fam.6.SW1.SW2 <- subset (SW1.SW2.data, Family == 6)

M27 <- glm (SW1.SW2 ~ Genotype, family = "binomial", data = Fam.6.SW1.SW2)
Anova (M27) 
r.squaredGLMM (M27)
lsmeans (M27, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.33 <- plot_model (M27, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.33 

# 1SW to 2SW
SW2.SW3.data <- subset (Seawater.data.v2, SW2.SW3 != "")
SW2.SW3.data$SW2.SW3 <- factor (SW2.SW3.data$SW2.SW3)
str (SW2.SW3.data)

plot.34 <- ggplot (SW2.SW3.data, aes (x = Genotype, fill = SW2.SW3)) +
  PlotTheme +
  geom_bar (position = "fill") 
plot.34 
plot.34 + facet_grid (. ~ Family)

# general
M28 <- glm (SW2.SW3 ~ Genotype, family = "binomial", data = SW2.SW3.data)
Anova (M28) 

# family 2
Fam.2.SW2.SW3 <- subset (SW2.SW3.data, Family == 2)

M29 <- glm (SW2.SW3 ~ Genotype, family = "binomial", data = Fam.2.SW2.SW3)
Anova (M29) # significant
r.squaredGLMM (M29)
lsmeans (M29, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.35 <- plot_model (M29, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.35 

# family 4
Fam.4.SW2.SW3 <- subset (SW2.SW3.data, Family == 4)

M30 <- glm (SW2.SW3 ~ Genotype, family = "binomial", data = Fam.4.SW2.SW3)
Anova (M30)
r.squaredGLMM (M30)
lsmeans (M30, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.36 <- plot_model (M30, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.36 

# family 6
Fam.6.SW2.SW3 <- subset (SW2.SW3.data, Family == 6)

M31 <- glm (SW2.SW3 ~ Genotype, family = "binomial", data = Fam.6.SW2.SW3)
Anova (M31) 
r.squaredGLMM (M31)
lsmeans (M31, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.37 <- plot_model (M31, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.37 

# family 8
Fam.8.SW2.SW3 <- subset (SW2.SW3.data, Family == 8)

M32 <- glm (SW2.SW3 ~ Genotype, family = "binomial", data = Fam.8.SW2.SW3)
Anova (M32) 
r.squaredGLMM (M32)
lsmeans (M32, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.38 <- plot_model (M32, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.38 

# 2SW to 2SW plus
SW3.plus.data <- subset (Seawater.data.v2, SW3.plus != "")
SW3.plus.data$SW3.plus <- factor (SW3.plus.data$SW3.plus)
str (SW3.plus.data)

plot.39 <- ggplot (SW3.plus.data, aes (x = Genotype, fill = SW3.plus)) +
  PlotTheme +
  geom_bar (position = "fill") 
plot.39 
plot.39 + facet_grid (. ~ Family)

# general
M33 <- glm (SW3.plus ~ Genotype, family = "binomial", data = SW3.plus.data)
Anova (M33)

# family 2
Fam.2.SW3plus <- subset (SW3.plus.data, Family == 2)

M34 <- glm (SW3.plus ~ Genotype, family = "binomial", data = Fam.2.SW3plus)
Anova (M34) 
r.squaredGLMM (M34)
lsmeans (M34, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.40 <- plot_model (M34, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.40 

# family 4
Fam.4.SW3plus <- subset (SW3.plus.data, Family == 4)

M35 <- glm (SW3.plus ~ Genotype, family = "binomial", data = Fam.4.SW3plus)
Anova (M35)
r.squaredGLMM (M35)
lsmeans (M35, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.41 <- plot_model (M35, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.41 

# family 6
Fam.6.SW3plus <- subset (SW3.plus.data, Family == 6)

M36 <- glm (SW3.plus ~ Genotype, family = "binomial", data = Fam.6.SW3plus)
Anova (M36)
r.squaredGLMM (M36)
lsmeans (M36, pairwise ~ Genotype, type = "response", adjust = "none") 

plot.42 <- plot_model (M36, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.42 

# family 8
Fam.8.SW3plus <- subset (SW3.plus.data, Family == 8)

M37 <- glm (SW3.plus ~ Genotype, family = "binomial", data = Fam.8.SW3plus)
Anova (M37) 
r.squaredGLMM (M37)
lsmeans (M37, pairwise ~ Genotype, type = "response", adjust = "none")

plot.43 <- plot_model (M37, type = "pred", terms = c("Genotype")) +
  labs (title = "", x = "Photoperiod", y = "Maturing (%)", tag = "") +
  theme (panel.background = element_rect (fill = "white", colour = "white")) +
  theme (axis.line = element_line(colour = "black"))
plot.43 

#### Size 1 year prior to maturation ####
## Seawater
# 2018
Seawater.size <- subset (Mat.2018, Experiment == "ST")

plot.44 <- ggplot (Seawater.size, aes (x = Previous.Weight, fill = Mature)) +
  geom_histogram (position = "identity", alpha = 0.4, binwidth = 10) +
  labs (x = "Body weight (g)", y = "Number of individuals") +
  PlotTheme 
plot.44

# 2019
Seawater.size <- subset (Seawater.data, Date > as.Date("2018-05-01") & Sex == "Male" & Mature != "NA")

#### Raw data check ####
plot.45 <- ggplot (Seawater.data, aes (x = Weight, y = Length, color = factor(Date))) + PlotTheme +
  geom_text (aes (label = Fish), size = 3) + 
  labs (x = "Body mass (g)", y = "Body length (cm)", tag = "")
plot.45  
plot.45 + facet_wrap (. ~ Date, scales = "free")

#### Figure 5 ####
Fig.5 <- ggplot (Seawater.size, aes (x = Previous.Weight, fill = Mature)) +
  geom_histogram (position = "identity", alpha = 0.4) +
  labs (x = "Body weight (g)", y = "Number of individuals") +
  facet_grid (Family ~ Date, scales = "free") 
Fig.5

#### Figure S3 ####
Fig.S3 <- ggplot (Seawater.size, aes (x = Previous.Length, fill = Mature)) +
  geom_histogram (position = "identity", alpha = 0.4) +
  labs (x = "Fork length (cm)", y = "Number of individuals") +
  facet_grid (Family ~ Date, scales = "free")  
Fig.S3

#### Figure S4 ####
Fig.S4 <- ggplot (Seawater.size, aes (x = Previous.Condition, fill = Mature)) +
  geom_histogram (position = "identity", alpha = 0.5) +
  labs (x = "Body condition (K factor)", y = "Number of individuals") +
  facet_grid (Family ~ Date, scales = "free") 
Fig.S4

#### FRESHWATER BODY SIZE ####
FW.size <- subset (Freshwater.data, Sex == "Male" & Genotype != "" & Theoretical != "No")
FW.size$Mature <- factor (FW.size$Mature)
str (FW.size)
table (FW.size$Family, FW.size$Genotype, FW.size$Mature)

# plot of length versus weight
plot.46 <- ggplot (FW.size, aes (x = Weight, y = Length, color = Mature)) + 
  PlotTheme +
  geom_text (aes (label = Fish), size = 3) + 
  labs (x = "Body mass (g)", y = "Body length (cm)", tag = "")
plot.46  
plot.46 + facet_grid (Family ~ Genotype, scales = "free")

# plot condition
plot.47 <- ggplot(subset (FW.size, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Family ~ .) +
  geom_hline (yintercept = .6) +
  geom_hline (yintercept = 1.8)
plot.47 

FW.size.edit <- subset (FW.size, Condition < 1.8)
FW.size.edit <- subset (FW.size, Condition > 0.8)

#### Weight and vgll3 genotype in freshwater ####
# family 6
FW.fam.6.size <- subset (FW.size.edit, Family == 6)
table (FW.fam.6.size$Genotype, FW.fam.6.size$Mature)

plot.48 <- ggplot(subset (FW.size, Family == 6), aes (x = Mature, y = Weight, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (g)") +
  PlotTheme
plot.48

# build a model
M38 <- lme (Weight ~ Genotype * Mature, random = ~1|Tank, method = "ML", data = FW.fam.6.size, na.action = "na.fail")

# fitted vs standardised residuals
plot (M38)
plot (M38, resid(., type = "p") ~ fitted(.) | Genotype,  abline = 0, grid = FALSE)
plot (M38, resid(., type = "p") ~ fitted(.) | Mature,  abline = 0, grid = FALSE)
plot (M38, resid(., type = "p") ~ fitted(.) | Tank,  abline = 0, grid = FALSE)

# qqplots
qqPlot (resid (M38), grid = FALSE, envelope = .95, line = "quartiles")
qqPlot (resid (M38), grid = FALSE, groups = FW.fam.6.size$Genotype, envelope =.95, line = "quartiles")
qqPlot (resid (M38), grid = FALSE, groups = FW.fam.6.size$Mature, envelope =.95, line = "quartiles")
qqPlot (resid (M38), grid = FALSE, groups = FW.fam.6.size$Tank, envelope =.95, line = "quartiles")

# model output
Anova (M38, type = 3)
Anova (M38, type = 2) 
r.squaredGLMM (M38) 

# post hoc
lsmeans (M38, pairwise ~ Mature, type = "response")
lsmeans (M38, pairwise ~ Genotype, type = "response")

# pick the best model
M39 <- dredge (M38, rank = AICc, trace = TRUE)
summary (model.avg (M39))
M40 <- lme (Weight ~ Mature, random = ~1|Tank, method = "ML", data = FW.fam.6.size, na.action = "na.fail")
Anova (M40, type = 2)
r.squaredGLMM (M40) 
lsmeans (M40, pairwise ~ Mature, type = "response")

# family 8
FW.fam.8.size <- subset (FW.size.edit, Family == 8)
table (FW.fam.8.size$Genotype, FW.fam.8.size$Mature)

plot.49 <- ggplot(subset (FW.size, Family == 8), aes (x = Mature, y = Weight, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (g)") +
  PlotTheme
plot.49

# build a model
M41 <- lme (Weight ~ Genotype * Mature, random = ~1|Tank, method = "ML", data = FW.fam.8.size, na.action = "na.fail")

# fitted vs standardised residuals
plot (M41)
plot (M41, resid(., type = "p") ~ fitted(.) | Genotype,  abline = 0, grid = FALSE)
plot (M41, resid(., type = "p") ~ fitted(.) | Mature,  abline = 0, grid = FALSE)
plot (M41, resid(., type = "p") ~ fitted(.) | Tank,  abline = 0, grid = FALSE)

# qqplots
qqPlot (resid (M41), grid = FALSE, envelope = .95, line = "quartiles")
qqPlot (resid (M41), grid = FALSE, groups = FW.fam.6.size$Genotype, envelope =.95, line = "quartiles")
qqPlot (resid (M41), grid = FALSE, groups = FW.fam.6.size$Mature, envelope =.95, line = "quartiles")
qqPlot (resid (M41), grid = FALSE, groups = FW.fam.6.size$Tank, envelope =.95, line = "quartiles")

# model output
Anova (M41, type = 3)
Anova (M41, type = 2) 
r.squaredGLMM (M41) 

# post hoc
lsmeans (M41, pairwise ~ Mature, type = "response")
lsmeans (M41, pairwise ~ Genotype, type = "response")
lsmeans (M41, pairwise ~ Mature | Genotype, type = "response")

# pick the best model
M42 <- dredge (M47, rank = AICc, trace = TRUE)
summary (model.avg (M42))
M43 <- lme (Weight ~ Mature, random = ~1|Tank, method = "ML", data = FW.fam.8.size, na.action = "na.fail")
Anova (M43, type = 2)
r.squaredGLMM (M43) 
lsmeans (M43, pairwise ~ Mature, type = "response")

#### Length and vgll3 genotype in freshwater ####
## family 6

# density plots
plot.50 <- ggplot(subset (FW.size, Family == 6), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme
plot.50

# build a model
M44 <- lme (Length ~ Genotype * Mature, random = ~1|Tank, method = "ML", data = FW.fam.6.size, na.action = "na.fail")

# fitted vs standardised residuals
plot (M44)
plot (M44, resid(., type = "p") ~ fitted(.) | Genotype,  abline = 0, grid = FALSE)
plot (M44, resid(., type = "p") ~ fitted(.) | Mature,  abline = 0, grid = FALSE)
plot (M44, resid(., type = "p") ~ fitted(.) | Tank,  abline = 0, grid = FALSE)

# qqplots
qqPlot (resid (M44), grid = FALSE, envelope = .95, line = "quartiles")
qqPlot (resid (M44), grid = FALSE, groups = FW.fam.6.size$Genotype, envelope =.95, line = "quartiles")
qqPlot (resid (M44), grid = FALSE, groups = FW.fam.6.size$Mature, envelope =.95, line = "quartiles")
qqPlot (resid (M44), grid = FALSE, groups = FW.fam.6.size$Tank, envelope =.95, line = "quartiles")

# model output
Anova (M44, type = 3)
Anova (M44, type = 2) 
r.squaredGLMM (M44) 

# post hoc
lsmeans (M44, pairwise ~ Mature, type = "response")
lsmeans (M44, pairwise ~ Genotype, type = "response")
lsmeans (M44, pairwise ~ Mature | Genotype, type = "response")
lsmeans (M44, pairwise ~ Mature * Genotype, type = "response")

# pick the best model
M45 <- dredge (M44, rank = AICc, trace = TRUE)
summary (model.avg (M45))
M46 <- lme (Length ~ Mature, random = ~1|Tank, method = "ML", data = FW.fam.6.size, na.action = "na.fail")
Anova (M46, type = 2)
r.squaredGLMM (M46) 
lsmeans (M46, pairwise ~ Mature, type = "response")

## stats for family 8
plot.51 <- ggplot(subset (FW.size, Family == 8), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme
plot.51

# build a model
M47 <- lme (Length ~ Genotype * Mature, random = ~1|Tank, method = "ML", data = FW.fam.8.size, na.action = "na.fail")

# fitted vs standardised residuals
plot (M47)
plot (M47, resid(., type = "p") ~ fitted(.) | Genotype,  abline = 0, grid = FALSE)
plot (M47, resid(., type = "p") ~ fitted(.) | Mature,  abline = 0, grid = FALSE)
plot (M47, resid(., type = "p") ~ fitted(.) | Tank,  abline = 0, grid = FALSE)

# qqplots
qqPlot (resid (M47), grid = FALSE, envelope = .95, line = "quartiles")
qqPlot (resid (M47), grid = FALSE, groups = FW.fam.6.size$Genotype, envelope =.95, line = "quartiles")
qqPlot (resid (M47), grid = FALSE, groups = FW.fam.6.size$Mature, envelope =.95, line = "quartiles")
qqPlot (resid (M47), grid = FALSE, groups = FW.fam.6.size$Tank, envelope =.95, line = "quartiles")

# model output
Anova (M47, type = 3)
Anova (M47, type = 2) 
r.squaredGLMM (M47) 

# post hoc
lsmeans (M47, pairwise ~ Mature, type = "response")
lsmeans (M47, pairwise ~ Genotype, type = "response")
lsmeans (M47, pairwise ~ Mature * Genotype, type = "response")

# pick the best model
M48 <- dredge (M47, rank = AICc, trace = TRUE)
summary (model.avg (M48))

# reflect the data
max (FW.fam.8.size$Length)
FW.fam.8.size$Reflect.length <- (43.5 + 1 - FW.fam.8.size$Length)

# build a model
M48 <- lme (log(Reflect.length) ~ Genotype * Mature, random = ~1|Tank, method = "ML", data = FW.fam.8.size, na.action = "na.fail")

# fitted vs standardised residuals
plot (M48)
plot (M48, resid(., type = "p") ~ fitted(.) | Genotype,  abline = 0, grid = FALSE)
plot (M48, resid(., type = "p") ~ fitted(.) | Mature,  abline = 0, grid = FALSE)
plot (M48, resid(., type = "p") ~ fitted(.) | Tank,  abline = 0, grid = FALSE)

# qqplots
qqPlot (resid (M48), grid = FALSE, envelope = .95, line = "quartiles")
qqPlot (resid (M48), grid = FALSE, groups = FW.fam.6.size$Genotype, envelope =.95, line = "quartiles")
qqPlot (resid (M48), grid = FALSE, groups = FW.fam.6.size$Mature, envelope =.95, line = "quartiles")
qqPlot (resid (M48), grid = FALSE, groups = FW.fam.6.size$Tank, envelope =.95, line = "quartiles")

# model output
Anova (M48, type = 3)
r.squaredGLMM (M48) 

# post hoc
lsmeans (M48, pairwise ~ Mature, type = "response")
lsmeans (M48, pairwise ~ Genotype, type = "response")
lsmeans (M48, pairwise ~ Mature * Genotype, type = "response")

marginal = lsmeans (M48, ~ Mature * Genotype, type = "response")
cld (marginal, alpha = 0.05, Letters = letters, reverse = TRUE)

# pick the best model
M49 <- dredge (M48, rank = AICc, trace = TRUE)
summary (model.avg (M49))

# non-parametric
FW.fam.8.size$Group <- paste (FW.fam.8.size$Genotype, FW.fam.8.size$Mature)
str (FW.fam.8.size)
M48.b <- kruskal.test (Length ~ Group, data = FW.fam.8.size) 
M48.b

dunn.test (FW.fam.8.size$Length, FW.fam.8.size$Group)  

#### Condition and vgll3 genotype in freshwater ####
## stats for family 6
plot.52 <- ggplot(subset (FW.size, Family == 6), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  annotate ("text", x = 1, y = 0.3, label = " (8) (14)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0.3, label = "(113) (116)", size = 5, color = "#636363") +
  PlotTheme
plot.52

# build a model
M50 <- lme (Condition ~ Genotype * Mature, random = ~1|Tank, method = "ML", data = FW.fam.6.size, na.action = "na.fail")

# fitted vs standardised residuals
plot (M50)
plot (M50, resid(., type = "p") ~ fitted(.) | Genotype,  abline = 0, grid = FALSE)
plot (M50, resid(., type = "p") ~ fitted(.) | Mature,  abline = 0, grid = FALSE)
plot (M50, resid(., type = "p") ~ fitted(.) | Tank,  abline = 0, grid = FALSE)

# qqplots
qqPlot (resid (M50), grid = FALSE, envelope = .95, line = "quartiles")
qqPlot (resid (M50), grid = FALSE, groups = FW.fam.6.size$Genotype, envelope =.95, line = "quartiles")
qqPlot (resid (M50), grid = FALSE, groups = FW.fam.6.size$Mature, envelope =.95, line = "quartiles")
qqPlot (resid (M50), grid = FALSE, groups = FW.fam.6.size$Tank, envelope =.95, line = "quartiles")

# model output
Anova (M50, type = 3)
r.squaredGLMM (M50) 

# post hoc
lsmeans (M50, pairwise ~ Mature * Genotype, type = "response")
lsmeans (M50, pairwise ~ Mature | Genotype, type = "response")
lsmeans (M50, pairwise ~ Genotype | Mature, type = "response")

# pick the best model
M51 <- dredge (M50, rank = AICc, trace = TRUE)
summary (model.avg (M51))

## stats for family 8
plot.53 <- ggplot(subset (FW.size, Family == 8), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  annotate ("text", x = 1, y = 0.3, label = " (11) (48)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0.3, label = "(88) (35)", size = 5, color = "#636363") +
  PlotTheme
plot.53

# build a model
M52 <- lme (Condition ~ Genotype * Mature, random = ~1|Tank, method = "ML", data = FW.fam.8.size, na.action = "na.fail")

# fitted vs standardised residuals
plot (M52)
plot (M52, resid(., type = "p") ~ fitted(.) | Genotype,  abline = 0, grid = FALSE)
plot (M52, resid(., type = "p") ~ fitted(.) | Mature,  abline = 0, grid = FALSE)
plot (M52, resid(., type = "p") ~ fitted(.) | Tank,  abline = 0, grid = FALSE)

# transform it
M52 <- lme (log(Condition) ~ Genotype * Mature, random = ~1|Tank, method = "ML", data = FW.fam.8.size, na.action = "na.fail")

# fitted vs standardised residuals
plot (M52)
plot (M52, resid(., type = "p") ~ fitted(.) | Genotype,  abline = 0, grid = FALSE)
plot (M52, resid(., type = "p") ~ fitted(.) | Mature,  abline = 0, grid = FALSE)
plot (M52, resid(., type = "p") ~ fitted(.) | Tank,  abline = 0, grid = FALSE)

# qqplots
qqPlot (resid (M52), grid = FALSE, envelope = .95, line = "quartiles")
qqPlot (resid (M52), grid = FALSE, groups = FW.fam.6.size$Genotype, envelope =.95, line = "quartiles")
qqPlot (resid (M52), grid = FALSE, groups = FW.fam.6.size$Mature, envelope =.95, line = "quartiles")
qqPlot (resid (M52), grid = FALSE, groups = FW.fam.6.size$Tank, envelope =.95, line = "quartiles")

# model output
Anova (M52, type = 3)
Anova (M52, type = 2) 
r.squaredGLMM (M52) 

# post hoc
lsmeans (M52, pairwise ~ Mature, type = "response")
lsmeans (M52, pairwise ~ Genotype, type = "response")
lsmeans (M52, pairwise ~ Mature | Genotype, type = "response")
lsmeans (M52, pairwise ~ Genotype | Mature, type = "response")
lsmeans (M52, pairwise ~ Genotype * Mature, type = "response")

marginal = lsmeans (M52, ~ Mature * Genotype, type = "response")
cld (marginal, alpha = 0.05, Letters = letters, reverse = TRUE)

# pick the best model
M53 <- dredge (M52, rank = AICc, trace = TRUE)
summary (model.avg (M53))
M54 <- lme (Condition ~ Mature, random = ~1|Tank, method = "ML", data = FW.fam.8.size, na.action = "na.fail")
Anova (M54, type = 2) 
r.squaredGLMM (M54) 
lsmeans (M54, pairwise ~ Mature, type = "response")

# non-parametric
M54.b <- kruskal.test (Condition ~ Group, data = FW.fam.8.size) 
M54.b

dunn.test (FW.fam.8.size$Condition, FW.fam.8.size$Group)  

tapply (FW.fam.8.size$Condition, FW.fam.8.size$Group, summary)

#### Figure 6 edits ####
plot.48.edit <- plot.48 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.text.x = element_blank ()) +
  labs (title = "Family 6") +
  ylim (0,1500)

plot.50.edit <- plot.50 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.text.x = element_blank ()) +
  ylim (10, 50)

plot.52.edit <- plot.52 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank ()) +
  ylim (0.3,2.5)

plot.49.edit <- plot.49 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.text.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.y = element_blank ()) +
  labs (title = "Family 8") +
  ylim (0,1500)

plot.51.edit <- plot.51 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.text.x = element_blank (),
         axis.title.y = element_blank (),
         axis.text.y = element_blank ()) +
  ylim (10, 50)

plot.53.edit <- plot.53 +
  theme (axis.text = element_text (size = 15),
         axis.title.y = element_blank (),
         axis.text.y = element_blank (),
         axis.title.x = element_blank ()) +
  ylim (0.3,2.5)

#### Figure S5 ####
grid.arrange (patchworkGrob(plot.48.edit + plot.49.edit + plot.50.edit +
                              plot.51.edit + plot.52.edit + plot.53.edit +
                              plot_layout (guides = "collect", widths = c(1,1)) & theme (legend.position = "right")),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### BODY SIZE AND VGLL3 IN SEAWATER ####
Seawater.data$Family <- factor (Seawater.data$Family)
Seawater.data$Genotype [Seawater.data$Genotype == "Early/Early"] <- "EE"
Seawater.data$Genotype [Seawater.data$Genotype == "Early/Late"] <- "EL"
Seawater.data$Genotype [Seawater.data$Genotype == "Late/Late"] <- "LL"
Seawater.data$MatGen <- paste (Seawater.data$Matured, Seawater.data$Genotype)
str (Seawater.data)

SW.growth <- subset (Seawater.data, Genotype != "" & Sex != "Female" & Theoretical != "No", 
                     select = c(Year,
                                Date,
                                Family, 
                                Fish, 
                                Genotype, 
                                Mature, 
                                Matured,
                                Next.year,
                                MatGen, 
                                Weight, 
                                Length, 
                                Condition))
SW.growth$Weight.kg <- SW.growth$Weight / 1000

plot.55 <- ggplot (SW.growth, aes(x = Year, y = Weight, group = Fish, color = Matured)) + PlotTheme +
  geom_line () +
  geom_point ()+
  labs (x = "Day", y = "Weight (g)")
plot.55
plot.55 + facet_grid (Family ~ Genotype)

# average weight of mature fish each year  
SW.growth.sub <- subset (SW.growth, Year == "2020")

tapply (SW.growth.sub$Weight, SW.growth.sub$Mature, summary)
tapply (SW.growth.sub$Length, SW.growth.sub$Mature, summary)

# check the n (divide the values by 4)
table (SW.Fam.2$Matured, SW.Fam.2$Genotype)

# family 2
SW.Fam.2 <- subset (SW.growth, Family == 2)

plot.56 <- ggplot(subset(SW.Fam.2, Date == "2018-04-16"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.56

plot.57 <- ggplot (subset(SW.Fam.2, Date == "2018-11-19"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.57

plot.58 <- ggplot (subset(SW.Fam.2, Year == 2019), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.58

plot.59 <- ggplot (subset(SW.Fam.2, Year == 2020), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.59

# make some edits so they go in a panel
plot.56.edt <- plot.56 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  theme (plot.title.position = "plot") +
  scale_y_continuous (breaks = seq (0, .32, .08), lim = c(0, .32)) +
  annotate ("text", x = .85, y = .32, label = "Apr 2018", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(15) (4) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(23) (29)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(1) (5)", size = 5, color = "#636363") 
plot.56.edt

plot.57.edt <- plot.57 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 2, .5), lim = c(0, 2)) +
  annotate ("text", x = .85, y = 2, label = "Nov 2018", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(15) (4) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(23) (29)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(1) (5)", size = 5, color = "#636363")  
plot.57.edt

plot.58.edt <- plot.58 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 12, 3), lim = c(0, 12)) +
  annotate ("text", x = .85, y = 12, label = "2019", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(15) (4) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(23) (29)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(1) (5)", size = 5, color = "#636363")  
plot.58.edt

plot.59.edt <- plot.59 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 24, 6), lim = c(0, 24)) +
  annotate ("text", x = .85, y = 24, label = "2020", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 2, y = 0, label = "(23) (29)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(1) (5)", size = 5, color = "#636363") 
plot.59.edt

Layout.3 <- "
AB
CD
"

grid.arrange (patchworkGrob(plot.56.edt / plot.57.edt / plot.58.edt / plot.59.edt +
                              plot_layout (guides = "collect", design = Layout.3) &
                              theme (legend.position = "top")),
              left = text_grob ("Body weight (kg)", size = 20, rot = 90, face = "bold"),
              bottom = text_grob ("Year of maturity", size = 20, face = "bold"))

# family 4
SW.Fam.4 <- subset (SW.growth, Family == 4)

plot.60 <- ggplot (subset (SW.Fam.4, Date == "2018-04-16"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.60 # due to missing group, the boxplot has been flipped

# add dummny group to df
Fam.4.dummy <- data.frame(Year = c(2018, 2018, 2019, 2020),
                          Date = c(43206,43423, 43787,44167),                     
                          Family = 4,
                          Fish = "",
                          Genotype = "LL",
                          Mature = "Yes",
                          Matured = 2019,
                          Next.year = "",
                          MatGen = "2019 LL",
                          Weight = "",
                          Length = "",
                          Condition = "",
                          Weight.kg = -10)
Fam.4.dummy
Fam.4.dummy$Date <- as.Date(Fam.4.dummy$Date, origin = "1899-12-30")

SW.Fam.4.dummy <- rbind (Fam.4.dummy, SW.Fam.4)
SW.Fam.4.dummy$Weight.kg <- as.numeric (SW.Fam.4.dummy$Weight.kg)
str (SW.Fam.4.dummy)

plot.60 <- ggplot (subset (SW.Fam.4.dummy, Date == "2018-04-16"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0.05, 0.3) +
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.60 

plot.61 <- ggplot (subset (SW.Fam.4.dummy, Date == "2018-11-19"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0.25, 2) +
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.61

plot.62 <- ggplot (subset (SW.Fam.4.dummy, Year == 2019), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (1, 14) +
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.62

plot.63 <- ggplot (subset (SW.Fam.4.dummy, Year == 2020), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (2, 25) +
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.63

# check the n (divide the values by 4)
SW.Fam.4.tbl <- table (SW.Fam.4$Matured, SW.Fam.4$Genotype)
SW.Fam.4.tbl

# make some edits so they go in a panel
plot.60.edt <- plot.60 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  theme (plot.title.position = "plot") +
  scale_y_continuous (breaks = seq (0, .32, .08), lim = c(0, .32)) +
  annotate ("text", x = .85, y = .32, label = "Apr 2018", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(6) (2) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(3) (0)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(38) (7)", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = 0, label = "(5) (17)", size = 5, color = "#636363") 
plot.60.edt

plot.61.edt <- plot.61 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 2, .5), lim = c(0, 2)) +
  annotate ("text", x = .85, y = 2, label = "Nov 2018", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(6) (2) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(3) (0)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(38) (7)", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = 0, label = "(5) (17)", size = 5, color = "#636363")   
plot.61.edt

plot.62.edt <- plot.62 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 12, 3), lim = c(0, 12)) +
  annotate ("text", x = .85, y = 12, label = "2019", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 2, y = 0, label = "(3) (0)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(38) (7)", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = 0, label = "(5) (17)", size = 5, color = "#636363")    
plot.62.edt

plot.63.edt <- plot.63 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 24, 6), lim = c(0, 24)) +
  annotate ("text", x = .85, y = 24, label = "2020", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 3, y = 0, label = "(38) (7)", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = 0, label = "(5) (17)", size = 5, color = "#636363")     
plot.63.edt

grid.arrange (patchworkGrob(plot.60.edt / plot.61.edt / plot.62.edt / plot.63.edt +
                              plot_layout (guides = "collect", design = Layout.3) &
                              theme (legend.position = "top")),
              left = text_grob ("Body weight (kg)", size = 20, rot = 90, face = "bold"),
              bottom = text_grob ("Year of maturity", size = 20, face = "bold"))

# family 6
SW.Fam.6 <- subset (SW.growth, Family == 6)

plot.64 <- ggplot(subset(SW.Fam.6, Date == "2018-04-16"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.64 # need some dummy groups

# need to include 2 dummy groups....
Fam.6.dummy.2018.EE <- data.frame (Year = c(2018, 2018, 2019, 2020),
                                   Date = c(43206,43423, 43787,44167),                    
                          Family = 6,
                          Fish = "",
                          Genotype = "EE",
                          Mature = "Yes",
                          Matured = 2018,
                          Next.year = "",
                          MatGen = "2018 EE",
                          Weight = "",
                          Length = "",
                          Condition = "",
                          Weight.kg = -10)
Fam.6.dummy.2018.EE 
Fam.6.dummy.2018.EE$Date <- as.Date(Fam.6.dummy.2018.EE$Date, origin = "1899-12-30")

SW.Fam.6.dummy <- rbind (Fam.6.dummy.2018.EE, SW.Fam.6)
SW.Fam.6.dummy$Weight.kg <- as.numeric (SW.Fam.6.dummy$Weight.kg)
str (SW.Fam.6.dummy)

plot.64 <- ggplot(subset(SW.Fam.6.dummy, Date == "2018-04-16"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0, .4) +
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.64 

plot.65 <- ggplot(subset(SW.Fam.6.dummy, Date == "2018-11-19"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0, 2) +
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.65

plot.66 <- ggplot(subset(SW.Fam.6.dummy, Year == 2019), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0, 12) +
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.66

plot.67 <- ggplot(subset(SW.Fam.6.dummy, Year == 2020), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0, 20) +
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.67

# check the n (divide the values by 4)
table (SW.Fam.6$Matured, SW.Fam.6$Genotype)

# make some edits so they go in a panel
plot.64.edt <- plot.64 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  theme (plot.title.position = "plot") +
  scale_y_continuous (breaks = seq (0, .32, .08), lim = c(0, .32)) +
  annotate ("text", x = .85, y = .32, label = "Apr 2018", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(0) (1) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(9) (1)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(30) (27)", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = 0, label = "(1) (4)", size = 5, color = "#636363") 
plot.64.edt

plot.65.edt <- plot.65 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 2, .5), lim = c(0, 2)) +
  annotate ("text", x = .85, y = 2, label = "Nov 2018", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(0) (1) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(9) (1)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(30) (27)", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = 0, label = "(1) (4)", size = 5, color = "#636363")  
plot.65.edt

plot.66.edt <- plot.66 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 12, 3), lim = c(0, 12)) +
  annotate ("text", x = .85, y = 12, label = "2019", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 2, y = 0, label = "(9) (1)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(30) (27)", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = 0, label = "(1) (4)", size = 5, color = "#636363")  
plot.66.edt

plot.67.edt <- plot.67 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 24, 6), lim = c(0, 24)) +
  annotate ("text", x = .85, y = 24, label = "2020", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 3, y = .02, label = "(30) (27)", size = 5, color = "#636363") +
  annotate ("text", x = 4, y = .02, label = "(1) (4)", size = 5, color = "#636363")  
plot.67.edt

grid.arrange (patchworkGrob(plot.64.edt / plot.65.edt / plot.66.edt / plot.67.edt +
                              plot_layout (guides = "collect", design = Layout.3) &
                              theme (legend.position = "top")),
              left = text_grob ("Body weight (kg)", size = 20, rot = 90, face = "bold"),
              bottom = text_grob ("Year of maturity", size = 20, face = "bold"))

# family 8
SW.Fam.8 <- subset (SW.growth, Family == 8)

plot.68 <- ggplot(subset(SW.Fam.8, Date == "2018-04-16" ), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.68 # need some dummy groups

# need to include 2 dummy groups....
Fam.8.dummy.2019.LL <- data.frame (Year = c(2018, 2018, 2019, 2020),
                                   Date = c(43206,43423, 43787,44167),                         
                                   Family = 8,
                                   Fish = "",
                                   Genotype = "LL",
                                   Mature = "Yes",
                                   Matured = 2019,
                                   Next.year = "",
                                   MatGen = "2019 EE",
                                   Weight = "",
                                   Length = "",
                                   Condition = "",
                                   Weight.kg = -10)
Fam.8.dummy.2019.LL 
Fam.8.dummy.2019.LL$Date <- as.Date(Fam.8.dummy.2019.LL$Date, origin = "1899-12-30")

Fam.8.dummy.never.EL <- data.frame (Year = c(2018, 2018, 2019, 2020),
                                    Date = c(43206,43423, 43787,44167),                       
                                   Family = 8,
                                   Fish = "",
                                   Genotype = "EL",
                                   Mature = "Yes",
                                   Matured = "Never",
                                   Next.year = "",
                                   MatGen = "Never EL",
                                   Weight = "",
                                   Length = "",
                                   Condition = "",
                                   Weight.kg = -10)
Fam.8.dummy.never.EL 
Fam.8.dummy.never.EL$Date <- as.Date(Fam.8.dummy.never.EL$Date, origin = "1899-12-30")

SW.Fam.8.dummy <- rbind (Fam.8.dummy.2019.LL, Fam.8.dummy.never.EL, SW.Fam.8)
SW.Fam.8.dummy$Weight.kg <- as.numeric (SW.Fam.8.dummy$Weight.kg)
str (SW.Fam.8.dummy)

plot.68 <- ggplot(subset(SW.Fam.8.dummy, Date == "2018-04-16"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0, .4) +
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.68 

plot.69 <- ggplot(subset(SW.Fam.8.dummy, Date == "2018-11-19"), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0, 2) +
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.69

plot.70 <- ggplot(subset(SW.Fam.8.dummy, Year == 2019), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0, 12) +
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.70

plot.71 <- ggplot(subset(SW.Fam.8.dummy, Year == 2020), aes (x = Matured, y = Weight.kg, fill = Genotype)) + 
  ylim (0, 25) +
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Body weight (kg)") +
  PlotTheme
plot.71

# check the n (divide the values by 4)
table (SW.Fam.8$Matured, SW.Fam.8$Genotype)

# make some edits so they go in a panel
plot.68.edt <- plot.68 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, .32, .08), lim = c(0, .32)) +
  annotate ("text", x = .85, y = .32, label = "Apr 2018", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(1) (0) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(43) (56)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(0) (25)", size = 5, color = "#636363") 
plot.68.edt

plot.69.edt <- plot.69 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.text.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 2, .5), lim = c(0, 2)) +
  annotate ("text", x = .85, y = 2, label = "Nov 2018", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(1) (0) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(43) (56)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(0) (25)", size = 5, color = "#636363")  
plot.69.edt

plot.70.edt <- plot.70 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 12, 3), lim = c(0, 12)) +
  annotate ("text", x = .85, y = 12, label = "2019", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 1, y = 0, label = "(1) (0) ", size = 5, color = "#636363") + 
  annotate ("text", x = 2, y = 0, label = "(43) (56)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(0) (25)", size = 5, color = "#636363")   
plot.70.edt

plot.71.edt <- plot.71 +
  theme (axis.title.x = element_blank ()) +
  theme (axis.title.y = element_blank ()) +
  scale_y_continuous (breaks = seq (0, 24, 6), lim = c(0, 24)) +
  annotate ("text", x = .85, y = 24, label = "2020", size = 8, color = "#636363", fontface = 2) + 
  annotate ("text", x = 2, y = 0, label = "(43) (56)", size = 5, color = "#636363") +
  annotate ("text", x = 3, y = 0, label = "(0) (25)", size = 5, color = "#636363")
plot.71.edt

grid.arrange (patchworkGrob(plot.68.edt / plot.69.edt / plot.70.edt / plot.71.edt +
                              plot_layout (guides = "collect", design = Layout.3) &
                              theme (legend.position = "top")),
              left = text_grob ("Body weight (kg)", size = 20, rot = 90, face = "bold"),
              bottom = text_grob ("Year of maturity", size = 20, face = "bold"))

#### Seawater growth stats - mature yes/no ####
### family 2 ####
SW.Fam.2.a2018 <- subset (SW.Fam.2, Date == "2018-04-16" & Mature != "")
SW.Fam.2.n2018 <- subset (SW.Fam.2, Date == "2018-11-19" & Mature != "")
SW.Fam.2.2019 <- subset (SW.Fam.2, Year == 2019 & Mature != "")
SW.Fam.2.2020 <- subset (SW.Fam.2, Year == 2020 & Mature != "")

## apr 2018
table (SW.Fam.2.a2018$Mature, SW.Fam.2.a2018$Genotype) 

plot.72 <- ggplot(subset (SW.Fam.2.a2018, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.72 

plot.73 <- ggplot(subset (SW.Fam.2.a2018, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.73 

plot.74 <- ggplot(subset (SW.Fam.2.a2018, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.74 

# weight
M55 <- glm (Weight ~ Genotype, data = SW.Fam.2.a2018)
par (mfrow = c(2,2))
plot (M55)
par (mfrow = c(1,1))

Anova (M55)
r.squaredGLMM (M55) 
lsmeans (M55, pairwise ~ Genotype)

# length
M56 <- glm (Length ~ Genotype, data = SW.Fam.2.a2018)
par (mfrow = c(2,2))
plot (M56)
par (mfrow = c(1,1))

Anova (M56)
r.squaredGLMM (M56) 
lsmeans (M56, pairwise ~ Genotype)

# condition
M57 <- glm (Condition ~ Genotype, data = SW.Fam.2.a2018)
par (mfrow = c(2,2))
plot (M57)
par (mfrow = c(1,1))

Anova (M57)
r.squaredGLMM (M57) 
lsmeans (M57, pairwise ~ Genotype)

## nov 2018
table (SW.Fam.2.n2018$Mature, SW.Fam.2.n2018$Genotype)

plot.75 <- ggplot(subset (SW.Fam.2.n2018, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.75 

plot.76 <- ggplot(subset (SW.Fam.2.n2018, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.76

plot.77 <- ggplot(subset (SW.Fam.2.n2018, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.77 

# weight
M58 <- glm (Weight ~ Genotype, data = SW.Fam.2.n2018)
par (mfrow = c(2,2))
plot (M58)
par (mfrow = c(1,1))

Anova (M58)
r.squaredGLMM (M58) 
lsmeans (M58, pairwise ~ Genotype)

# length
M59 <- glm (Length ~ Genotype, data = SW.Fam.2.n2018)
par (mfrow = c(2,2))
plot (M59)
par (mfrow = c(1,1))

Anova (M59)
r.squaredGLMM (M59) 
lsmeans (M59, pairwise ~ Genotype)

# condition
M60 <- glm (Condition ~ Genotype, data = SW.Fam.2.n2018)
par (mfrow = c(2,2))
plot (M60)
par (mfrow = c(1,1))

Anova (M60)
r.squaredGLMM (M60) 
lsmeans (M60, pairwise ~ Genotype)

## 2019
table (SW.Fam.2.2019$Mature, SW.Fam.2.2019$Genotype) 

plot.78 <- ggplot(subset (SW.Fam.2.2019, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.78 

plot.79 <- ggplot(subset (SW.Fam.2.2019, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.79 

plot.80 <- ggplot(subset (SW.Fam.2.2019, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.80 

# weight
M61 <- glm (Weight ~ Mature * Genotype, data = SW.Fam.2.2019)
par (mfrow = c(2,2))
plot (M61)
par (mfrow = c(1,1))

Anova (M61)
Anova (M61, type = 3)

r.squaredGLMM (M61)
lsmeans (M61, pairwise ~ Genotype)
lsmeans (M61, pairwise ~ Mature)

# length
M62 <- glm (Length ~ Mature * Genotype, data = SW.Fam.2.2019)
par (mfrow = c(2,2))
plot (M62)
par (mfrow = c(1,1))

Anova (M62, type = 3)
Anova (M62)
r.squaredGLMM (M62)
lsmeans (M62, pairwise ~ Genotype)
lsmeans (M62, pairwise ~ Mature)

# condition
M63 <- glm (Condition ~ Mature * Genotype, data = SW.Fam.2.2019)
par (mfrow = c(2,2))
plot (M63)
par (mfrow = c(1,1))

Anova (M63, type = 3)
Anova (M63)
r.squaredGLMM (M63)
lsmeans (M63, pairwise ~ Genotype)
lsmeans (M63, pairwise ~ Mature)

## 2020
table (SW.Fam.2.2020$Mature, SW.Fam.2.2020$Genotype) 

plot.81 <- ggplot(subset (SW.Fam.2.2020, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.81 

plot.82 <- ggplot(subset (SW.Fam.2.2020, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.82 

plot.83 <- ggplot(subset (SW.Fam.2.2020, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.83 

# weight
M64 <- glm (Weight ~ Mature + Genotype, data = SW.Fam.2.2020)
par (mfrow = c(2,2))
plot (M64)
par (mfrow = c(1,1))

Anova (M64)
r.squaredGLMM (M64)
lsmeans (M64, pairwise ~ Genotype)
lsmeans (M64, pairwise ~ Mature)

# length
M65 <- glm (Length ~ Mature + Genotype, data = SW.Fam.2.2020)
par (mfrow = c(2,2))
plot (M65)
par (mfrow = c(1,1))

Anova (M65)
r.squaredGLMM (M65)
lsmeans (M65, pairwise ~ Genotype)
lsmeans (M65, pairwise ~ Mature)

# condition
M66 <- glm (Condition ~ Mature + Genotype, data = SW.Fam.2.2020)
par (mfrow = c(2,2))
plot (M66)
par (mfrow = c(1,1))

Anova (M66)
r.squaredGLMM (M66)
lsmeans (M66, pairwise ~ Genotype)
lsmeans (M66, pairwise ~ Mature)

#### figure S6 edits - family 2 body weight ####
# edits
plot.72.edt <- plot.72 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0,.25) +
  annotate ("text", x = 1, y = .0, label = "(39) (38)", size = 5, color = "#636363") 

plot.75.edt <- plot.75 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0,2) +
  annotate ("text", x = 1, y = 0, label = "(39) (38)", size = 5, color = "#636363")  
  
plot.78.edt <- plot.78 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (3, 12) +
  annotate ("text", x = 1, y = 3, label = "(24) (34)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 3, label = "(15) (4)", size = 5, color = "#636363")  

plot.81.edt <- plot.81 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0, 25) +
  annotate ("text", x = 1, y = 0, label = "(1) (5)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0, label = "(23) (29)", size = 5, color = "#636363")   
  
grid.arrange (patchworkGrob(plot.72.edt + plot.75.edt + plot.78.edt + plot.81.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Weight (kg)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### figure S7 edits - family 2 length ####
# edits
plot.73.edt <- plot.73 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (15,30) +
  annotate ("text", x = 1, y = 15, label = "(39) (38)", size = 5, color = "#636363") 

plot.76.edt <- plot.76 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (30,60) +
  annotate ("text", x = 1, y = 30, label = "(39) (38)", size = 5, color = "#636363")  

plot.79.edt <- plot.79 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (65, 95) +
  annotate ("text", x = 1, y = 65, label = "(24) (34)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 65, label = "(15) (4)", size = 5, color = "#636363")  

plot.82.edt <- plot.82 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (80, 120) +
  annotate ("text", x = 1, y = 80, label = "(1) (5)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 80, label = "(23) (29)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.73.edt + plot.76.edt + plot.79.edt + plot.82.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Length (cm)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### figure S8 edits - family 2 condition ####
# edits
plot.74.edt <- plot.74 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (1, 1.5) +
  annotate ("text", x = 1, y = 1, label = "(39) (38)", size = 5, color = "#636363") 

plot.77.edt <- plot.77 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (1, 1.5) +
  annotate ("text", x = 1, y = 1, label = "(39) (38)", size = 5, color = "#636363")  

plot.80.edt <- plot.80 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (.9, 1.75) +
  annotate ("text", x = 1, y = .9, label = "(24) (34)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = .9, label = "(15) (4)", size = 5, color = "#636363")  

plot.83.edt <- plot.83 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0.5, 1.5) +
  annotate ("text", x = 1, y = 0.5, label = "(1) (5)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0.5, label = "(23) (29)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.74.edt + plot.77.edt + plot.80.edt + plot.83.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Condition (K factor)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

### family 4 ####
SW.Fam.4.a2018 <- subset (SW.Fam.4, Date == "2018-04-16" & Mature != "")
SW.Fam.4.n2018 <- subset (SW.Fam.4, Date == "2018-11-19" & Mature != "")
SW.Fam.4.2019 <- subset (SW.Fam.4, Year == 2019 & Mature != "")
SW.Fam.4.2020 <- subset (SW.Fam.4, Year == 2020 & Mature != "")

## apr 2018
table (SW.Fam.4.a2018$Mature, SW.Fam.4.a2018$Genotype) 

plot.84 <- ggplot(subset (SW.Fam.4.a2018, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.84

plot.85 <- ggplot(subset (SW.Fam.4.a2018, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.85 

plot.86 <- ggplot(subset (SW.Fam.4.a2018, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.86 

# weight
M67 <- glm (Weight ~ Genotype, data = SW.Fam.4.a2018)
par (mfrow = c(2,2))
plot (M67)
par (mfrow = c(1,1))

Anova (M67)
r.squaredGLMM (M67)
lsmeans (M67, pairwise ~ Genotype)

# length
M68 <- glm (Length ~ Genotype, data = SW.Fam.4.a2018)
par (mfrow = c(2,2))
plot (M68)
par (mfrow = c(1,1))

Anova (M68)
r.squaredGLMM (M68)
lsmeans (M68, pairwise ~ Genotype)

# condition
M69 <- glm (Condition ~ Genotype, data = SW.Fam.4.a2018)
par (mfrow = c(2,2))
plot (M69)
par (mfrow = c(1,1))

Anova (M69)
r.squaredGLMM (M69)
lsmeans (M69, pairwise ~ Genotype)

## nov 2018
table (SW.Fam.4.n2018$Mature, SW.Fam.4.n2018$Genotype) 

plot.87 <- ggplot(subset (SW.Fam.4.n2018, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.87 

plot.88 <- ggplot(subset (SW.Fam.4.n2018, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.88 

plot.89 <- ggplot(subset (SW.Fam.4.n2018, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.89

# weight
M70 <- glm (Weight ~ Mature + Genotype, data = SW.Fam.4.n2018)
par (mfrow = c(2,2))
plot (M70)
par (mfrow = c(1,1))

Anova (M70)
r.squaredGLMM (M70)
lsmeans (M70, pairwise ~ Genotype)
lsmeans (M70, pairwise ~ Mature)

# length
M71 <- glm (Length ~ Mature + Genotype, data = SW.Fam.4.n2018)
par (mfrow = c(2,2))
plot (M71)
par (mfrow = c(1,1))

Anova (M71)
r.squaredGLMM (M71)
lsmeans (M71, pairwise ~ Genotype)
lsmeans (M71, pairwise ~ Mature)

# condition
M72 <- glm (Condition ~ Mature + Genotype, data = SW.Fam.4.n2018)
par (mfrow = c(2,2))
plot (M72)
par (mfrow = c(1,1))

Anova (M72)
r.squaredGLMM (M72)
lsmeans (M72, pairwise ~ Genotype)
lsmeans (M72, pairwise ~ Mature)

## 2019
table (SW.Fam.4.2019$Mature, SW.Fam.4.2019$Genotype) 

plot.90 <- ggplot(subset (SW.Fam.4.2019, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values = c("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.90

plot.91 <- ggplot(subset (SW.Fam.4.2019, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values = c("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.91

plot.92 <- ggplot(subset (SW.Fam.4.2019, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values = c("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.92

# weight
M73 <- glm (Weight ~ Mature + Genotype, data = SW.Fam.4.2019)
par (mfrow =c(2,2))
plot (M73)
par (mfrow =c(1,1))

Anova (M73)
r.squaredGLMM (M73)
lsmeans (M73, pairwise ~ Genotype)
lsmeans (M73, pairwise ~ Mature)

# length
M74 <- glm (Length ~ Mature + Genotype, data = SW.Fam.4.2019)
par (mfrow =c(2,2))
plot (M74)
par (mfrow =c(1,1))

Anova (M74)
r.squaredGLMM (M74)
lsmeans (M74, pairwise ~ Genotype)
lsmeans (M74, pairwise ~ Mature)

# condition
M75 <- glm (Condition ~ Mature + Genotype, data = SW.Fam.4.2019)
par (mfrow =c(2,2))
plot (M75)
par (mfrow =c(1,1))

Anova (M75)
r.squaredGLMM (M75)
lsmeans (M75, pairwise ~ Genotype)
lsmeans (M75, pairwise ~ Mature)

max (SW.Fam.4.2019$Condition)

SW.Fam.4.2019.cond <- subset (SW.Fam.4.2019, Condition <2)
M76 <- glm (Condition ~ Genotype + Mature, data = SW.Fam.4.2019.cond)
par (mfrow =c(2,2))
plot (M76)
par (mfrow =c(1,1))

Anova (M76)
r.squaredGLMM (M76)
lsmeans (M76, pairwise ~ Genotype)
lsmeans (M76, pairwise ~ Mature)

## 2020
table (SW.Fam.4.2020$Mature, SW.Fam.4.2020$Genotype)

plot.93 <- ggplot(subset (SW.Fam.4.2020, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.93

plot.94 <- ggplot(subset (SW.Fam.4.2020, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.94 

plot.95 <- ggplot(subset (SW.Fam.4.2020, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.95 

# weight
M77 <- glm (Weight ~ Genotype * Mature, data = SW.Fam.4.2020)
par (mfrow =c(2,2))
plot (M77)
par (mfrow =c(1,1))

Anova (M77, type = 3)
Anova (M77, type = 2)
r.squaredGLMM (M77)
lsmeans (M77, pairwise ~ Genotype)
lsmeans (M77, pairwise ~ Mature)

# length
M78 <- glm (Length ~ Genotype * Mature, data = SW.Fam.4.2020)
par (mfrow =c(2,2))
plot (M78)
par (mfrow =c(1,1))

Anova (M78, type = 3)
Anova (M78, type = 2)
r.squaredGLMM (M78)
lsmeans (M78, pairwise ~ Genotype)
lsmeans (M78, pairwise ~ Mature)

# condition
M79 <- glm (Condition ~ Genotype * Mature, data = SW.Fam.4.2020)
par (mfrow =c(2,2))
plot (M79)
par (mfrow =c(1,1))

Anova (M79, type = 3)
Anova (M79, type = 2)
r.squaredGLMM (M79)
lsmeans (M79, pairwise ~ Genotype)
lsmeans (M79, pairwise ~ Mature)

#### figure S9 edits - family 4 body weight ####
# edits
plot.84.edt <- plot.84 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0,.35) +
  annotate ("text", x = 1, y = .0, label = "(52) (26)", size = 5, color = "#636363") 

plot.87.edt <- plot.87 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0,2) +
  annotate ("text", x = 1, y = 0, label = "(45) (24)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0, label = "(6) (2)", size = 5, color = "#636363")  

plot.90.edt <- plot.90 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0, 12) +
  annotate ("text", x = 1, y = 0, label = "(43) (24)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0, label = "(3) (0)", size = 5, color = "#636363")  

plot.93.edt <- plot.93 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0, 25) +
  annotate ("text", x = 1, y = 0, label = "(5) (17)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0, label = "(38) (7)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.84.edt + plot.87.edt + plot.90.edt + plot.93.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Weight (kg)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### figure S10 edits - family 4 length ####
# edits
plot.85.edt <- plot.85 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (15,30) +
  annotate ("text", x = 1, y = 15, label = "(52) (26)", size = 5, color = "#636363") 

plot.88.edt <- plot.88 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (30,60) +
  annotate ("text", x = 1, y = 30, label = "(45) (24)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 30, label = "(6) (2)", size = 5, color = "#636363")  

plot.91.edt <- plot.91 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (55, 95) +
  annotate ("text", x = 1, y = 55, label = "(43) (24)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 55, label = "(3) (0)", size = 5, color = "#636363")  

plot.94.edt <- plot.94 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (80, 120) +
  annotate ("text", x = 1, y = 80, label = "(5) (17)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 80, label = "(38) (7)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.85.edt + plot.88.edt + plot.91.edt + plot.94.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Length (cm)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### figure S11 edits - family 4 condition ####
# edits
plot.86.edt <- plot.86 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0.75, 1.5) +
  annotate ("text", x = 1, y = 0.75, label = "(52) (26)", size = 5, color = "#636363") 

plot.89.edt <- plot.89 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0.75, 1.5) +
  annotate ("text", x = 1, y = 0.75, label = "(45) (24)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0.75, label = "(6) (2)", size = 5, color = "#636363")  

plot.92.edt <- plot.92 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0.75, 1.75) +
  annotate ("text", x = 1, y = 0.75, label = "(43) (24)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0.75, label = "(3) (0)", size = 5, color = "#636363")  

plot.95.edt <- plot.95 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0.5, 1.7) +
  annotate ("text", x = 1, y = 0.5, label = "(5) (17)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0.5, label = "(38) (7)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.86.edt + plot.89.edt + plot.92.edt + plot.95.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Condition (K factor)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

### family 6 ####
SW.Fam.6.a2018 <- subset (SW.Fam.6, Date == "2018-04-16")
SW.Fam.6.n2018 <- subset (SW.Fam.6, Date == "2018-11-19")
SW.Fam.6.2019 <- subset (SW.Fam.6, Year == 2019)
SW.Fam.6.2020 <- subset (SW.Fam.6, Year == 2020)

## apr 2018
table (SW.Fam.6.a2018$Mature, SW.Fam.6.a2018$Genotype) 

plot.95 <- ggplot(subset (SW.Fam.6.a2018, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.95 

plot.96 <- ggplot(subset (SW.Fam.6.a2018, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.96 

plot.97 <- ggplot(subset (SW.Fam.6.a2018, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.97 

# weight
M80 <- glm (Weight ~ Genotype, data = SW.Fam.6.a2018)
par (mfrow =c(2,2))
plot (M80)
par (mfrow =c(1,1))

Anova (M80)
r.squaredGLMM (M80)
lsmeans (M80, pairwise ~ Genotype)

# length
M81 <- glm (Length ~ Genotype, data = SW.Fam.6.a2018)
par (mfrow =c(2,2))
plot (M81)
par (mfrow =c(1,1))

Anova (M81)
r.squaredGLMM (M81)
lsmeans (M81, pairwise ~ Genotype)

# condition
M82 <- glm (Condition ~ Genotype, data = SW.Fam.6.a2018)
par (mfrow =c(2,2))
plot (M82)
par (mfrow =c(1,1))

Anova (M82)
r.squaredGLMM (M82)
lsmeans (M82, pairwise ~ Genotype)

## nov 2018
table (SW.Fam.6.n2018$Mature, SW.Fam.6.n2018$Genotype)

plot.98 <- ggplot(subset (SW.Fam.6.n2018, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.98 

plot.99 <- ggplot(subset (SW.Fam.6.n2018, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.99 

plot.100 <- ggplot(subset (SW.Fam.6.n2018, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.100 

# weight
M83 <- glm (Weight ~ Genotype, data = SW.Fam.6.n2018)
par (mfrow =c(2,2))
plot (M83)
par (mfrow =c(1,1))

Anova (M83)
r.squaredGLMM (M83)
lsmeans (M83, pairwise ~ Genotype)

# length
M84 <- glm (Length ~ Genotype, data = SW.Fam.6.n2018)
par (mfrow =c(2,2))
plot (M84)
par (mfrow =c(1,1))

Anova (M84)
r.squaredGLMM (M84)
lsmeans (M84, pairwise ~ Genotype)

# condition
M85 <- glm (Condition ~ Genotype, data = SW.Fam.6.n2018)
par (mfrow =c(2,2))
plot (M85)
par (mfrow =c(1,1))

Anova (M85)
r.squaredGLMM (M85)
lsmeans (M85, pairwise ~ Genotype)

## 2019
table (SW.Fam.6.2019$Mature, SW.Fam.6.2019$Genotype) 

plot.101 <- ggplot(subset (SW.Fam.6.2019, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.101 

plot.102 <- ggplot(subset (SW.Fam.6.2019, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.102 

plot.103 <- ggplot(subset (SW.Fam.6.2019, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.103 

# weight
M86 <- glm (Weight ~ Genotype + Mature, data = SW.Fam.6.2019)
par (mfrow =c(2,2))
plot (M86)
par (mfrow =c(1,1))

Anova (M86)
r.squaredGLMM (M86)
lsmeans (M86, pairwise ~ Genotype)
lsmeans (M86, pairwise ~ Mature)

# length
M87 <- glm (Length ~ Mature + Genotype, data = SW.Fam.6.2019)
par (mfrow =c(2,2))
plot (M87)
par (mfrow =c(1,1))

Anova (M87)
r.squaredGLMM (M87)
lsmeans (M87, pairwise ~ Genotype)
lsmeans (M87, pairwise ~ Mature)

# condition
M88 <- glm (Condition ~ Mature + Genotype, data = SW.Fam.6.2019)
par (mfrow =c(2,2))
plot (M88)
par (mfrow =c(1,1))

Anova (M88)
r.squaredGLMM (M88)
lsmeans (M88, pairwise ~ Genotype)
lsmeans (M88, pairwise ~ Mature)

SW.Fam.6.2019.edt <- subset (SW.Fam.6.2019, Condition !="")
max (SW.Fam.6.2019.edt$Condition)

SW.Fam.6.2019.cond <- subset (SW.Fam.6.2019, Condition < 2)
M89 <- glm (Condition ~ Genotype + Mature, data = SW.Fam.6.2019.cond)
par (mfrow =c(2,2))
plot (M89)
par (mfrow =c(1,1))

Anova (M89)
r.squaredGLMM (M89)
lsmeans (M89, pairwise ~ Genotype)
lsmeans (M89, pairwise ~ Mature)

## 2020
table (SW.Fam.6.2020$Mature, SW.Fam.6.2020$Genotype) 

plot.104 <- ggplot(subset (SW.Fam.6.2020, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.104 

plot.105 <- ggplot(subset (SW.Fam.6.2020, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.105 

plot.106 <- ggplot(subset (SW.Fam.6.2020, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#00a9e0", "#59c7eb")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.106 

# weight
M90 <- glm (Weight ~ Genotype + Mature, data = SW.Fam.6.2020)
par (mfrow =c(2,2))
plot (M90)
par (mfrow =c(1,1))

Anova (M90)
r.squaredGLMM (M90)
lsmeans (M90, pairwise ~ Genotype)
lsmeans (M90, pairwise ~ Mature)

# length
M91 <- glm (Length ~ Genotype + Mature, data = SW.Fam.6.2020)
par (mfrow =c(2,2))
plot (M91)
par (mfrow =c(1,1))

Anova (M91)
r.squaredGLMM (M91)
lsmeans (M91, pairwise ~ Genotype)
lsmeans (M91, pairwise ~ Mature)

# condition
M92 <- glm (Condition ~ Genotype + Mature, data = SW.Fam.6.2020)
par (mfrow =c(2,2))
plot (M92)
par (mfrow =c(1,1))

Anova (M92)
r.squaredGLMM (M92)
lsmeans (M92, pairwise ~ Genotype)
lsmeans (M92, pairwise ~ Mature)

#### figure S12 edits - family 6 body weight ####
# edits
plot.95.edt <- plot.95 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0,.3) +
  annotate ("text", x = 1, y = .0, label = "(40) (33)", size = 5, color = "#636363") 

plot.98.edt <- plot.98 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0,2) +
  annotate ("text", x = 1, y = 0, label = "(40) (32)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0, label = "(0) (1)", size = 5, color = "#636363")  

plot.101.edt <- plot.101 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0, 12) +
  annotate ("text", x = 1, y = 0, label = "(31) (31)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0, label = "(9) (1)", size = 5, color = "#636363")  

plot.104.edt <- plot.104 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0, 25) +
  annotate ("text", x = 1, y = 0, label = "(1) (4)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0, label = "(30) (27)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.95.edt + plot.98.edt + plot.101.edt + plot.104.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Weight (kg)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### figure S13 edits - family 6 length ####
# edits
plot.96.edt <- plot.96 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (15,30) +
  annotate ("text", x = 1, y = 15, label = "(40) (33)", size = 5, color = "#636363") 

plot.99.edt <- plot.99 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (30,60) +
  annotate ("text", x = 1, y = 30, label = "(40) (32)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 30, label = "(0) (1)", size = 5, color = "#636363")  

plot.102.edt <- plot.102 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (55, 95) +
  annotate ("text", x = 1, y = 55, label = "(31) (31)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 55, label = "(9) (1)", size = 5, color = "#636363")  

plot.105.edt <- plot.105 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (80, 120) +
  annotate ("text", x = 1, y = 80, label = "(1) (4)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 80, label = "(30) (27)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.96.edt + plot.99.edt + plot.102.edt + plot.105.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Length (cm)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### figure S14 edits - family 6 condition ####
# edits
plot.97.edt <- plot.97 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (1, 1.5) +
  annotate ("text", x = 1, y = 1, label = "(40) (33)", size = 5, color = "#636363") 

plot.100.edt <- plot.100 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (1, 1.5) +
  annotate ("text", x = 1, y = 1, label = "(40) (32)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 1, label = "(0) (1)", size = 5, color = "#636363")  

plot.103.edt <- plot.103 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (1, 2.25) +
  annotate ("text", x = 1, y = 1, label = "(31) (31)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 1, label = "(9) (1)", size = 5, color = "#636363")  

plot.106.edt <- plot.106 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0.5, 1.7) +
  annotate ("text", x = 1, y = 0.5, label = "(1) (4)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0.5, label = "(30) (27)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.97.edt + plot.100.edt + plot.103.edt + plot.106.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Condition (K factor)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

### family 8 ####
SW.Fam.8.a2018 <- subset (SW.Fam.8, Date == "2018-04-16")
SW.Fam.8.n2018 <- subset (SW.Fam.8, Date == "2018-11-19")
SW.Fam.8.2019 <- subset (SW.Fam.8, Year == 2019)
SW.Fam.8.2020 <- subset (SW.Fam.8, Year == 2020)

## apr 2018
table (SW.Fam.8.a2018$Mature, SW.Fam.8.a2018$Genotype) 

plot.107 <- ggplot(subset (SW.Fam.8.a2018, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.107 

plot.108 <- ggplot(subset (SW.Fam.8.a2018, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.108 

plot.109 <- ggplot(subset (SW.Fam.8.a2018, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.109 

# weight
M93 <- glm (Weight ~ Genotype, data = SW.Fam.8.a2018)
par (mfrow =c(2,2))
plot (M93)
par (mfrow =c(1,1))

Anova (M93)
r.squaredGLMM (M93)
lsmeans (M93, pairwise ~ Genotype)

# length
M94 <- glm (Length ~ Genotype, data = SW.Fam.8.a2018)
par (mfrow =c(2,2))
plot (M94)
par (mfrow =c(1,1))

Anova (M94)
r.squaredGLMM (M94)
lsmeans (M94, pairwise ~ Genotype)

# condition
M95 <- glm (Condition ~ Genotype, data = SW.Fam.8.a2018)
par (mfrow =c(2,2))
plot (M95)
par (mfrow =c(1,1))

Anova (M95)
r.squaredGLMM (M95)
lsmeans (M95, pairwise ~ Genotype)

min (SW.Fam.8.a2018$Condition)

SW.Fam.8.a2018.cond <- subset (SW.Fam.8.a2018, Condition > 1)
M96 <- glm (Condition ~ Genotype, data = SW.Fam.8.a2018.cond)
par (mfrow =c(2,2))
plot (M96)
par (mfrow =c(1,1))

Anova (M96)
r.squaredGLMM (M96)
lsmeans (M96, pairwise ~ Genotype)

## nov 2018
table (SW.Fam.8.n2018$Mature, SW.Fam.8.n2018$Genotype) 

plot.110 <- ggplot(subset (SW.Fam.8.n2018, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.110 

plot.111 <- ggplot(subset (SW.Fam.8.n2018, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.111 

plot.112 <- ggplot(subset (SW.Fam.8.n2018, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.112 

# weight
M97 <- glm (Weight ~ Genotype, data = SW.Fam.8.n2018)
par (mfrow =c(2,2))
plot (M97)
par (mfrow =c(1,1))

Anova (M97)
r.squaredGLMM (M97)
lsmeans (M97, pairwise ~ Genotype)

# length
M98 <- glm (Length ~ Genotype, data = SW.Fam.8.n2018)
par (mfrow =c(2,2))
plot (M98)
par (mfrow =c(1,1))

Anova (M98)
r.squaredGLMM (M98)
lsmeans (M98, pairwise ~ Genotype)

# condition
M99 <- glm (Condition ~ Genotype, data = SW.Fam.8.n2018)
par (mfrow =c(2,2))
plot (M99)
par (mfrow =c(1,1))

Anova (M99)
r.squaredGLMM (M99)
lsmeans (M99, pairwise ~ Genotype)

## 2019
table (SW.Fam.8.2019$Mature, SW.Fam.8.2019$Genotype) 

plot.113 <- ggplot(subset (SW.Fam.8.2019, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.113 

plot.114 <- ggplot(subset (SW.Fam.8.2019, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.114 

plot.115 <- ggplot(subset (SW.Fam.8.2019, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.115 

# weight
M100 <- glm (Weight ~ Genotype, data = SW.Fam.8.2019)
par (mfrow =c(2,2))
plot (M100)
par (mfrow =c(1,1))

Anova (M100)
r.squaredGLMM (M100)
lsmeans (M100, pairwise ~ Genotype)

# length
M101 <- glm (Length ~ Genotype, data = SW.Fam.8.2019)
par (mfrow =c(2,2))
plot (M101)
par (mfrow =c(1,1))

Anova (M101)
r.squaredGLMM (M101)
lsmeans (M101, pairwise ~ Genotype)

# condition
M102 <- glm (Condition ~ Genotype, data = SW.Fam.8.2019)
par (mfrow =c(2,2))
plot (M102)
par (mfrow =c(1,1))

Anova (M102)
r.squaredGLMM (M102)
lsmeans (M102, pairwise ~ Genotype)

## 2020
table (SW.Fam.8.2020$Mature, SW.Fam.8.2020$Genotype) 

plot.116 <- ggplot(subset (SW.Fam.8.2020, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.116 

# include a dummy group
Fam.8.dummy <- data.frame(Year = 2020, 
                          Date = "2020-12-02",
                          Family = 8,
                          Fish = "Made-up",
                          Genotype = "EL",
                          Mature = "No",
                          Matured = "",
                          Next.year = "",
                          MatGen = "2020 EL",
                          Weight = "",
                          Length = "",
                          Condition = "",
                          Weight.kg = -10)
Fam.8.dummy
Fam.8.dummy$Date <- as.Date(Fam.8.dummy$Date, origin="1899-12-30")

SW.Fam.8.dummy <- rbind (Fam.8.dummy, SW.Fam.8.2020)
SW.Fam.8.dummy$Weight.kg <- as.numeric (SW.Fam.8.dummy$Weight.kg)
SW.Fam.8.dummy$Length <- as.numeric (SW.Fam.8.dummy$Length)
SW.Fam.8.dummy$Condition <- as.numeric (SW.Fam.8.dummy$Condition)
str (SW.Fam.8.dummy)

plot.116 <- ggplot(subset (SW.Fam.8.dummy, Mature != ""), aes (x = Mature, y = Weight.kg, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Weight (kg)") +
  PlotTheme +
  ylim (0, 25) +
  facet_wrap (Date ~ .)
plot.116 

plot.117 <- ggplot(subset (SW.Fam.8.dummy, Mature != ""), aes (x = Mature, y = Length, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Length (cm)") +
  PlotTheme + 
  facet_wrap (Date ~ .)
plot.117 

plot.118 <- ggplot(subset (SW.Fam.8.dummy, Mature != ""), aes (x = Mature, y = Condition, fill = Genotype)) + 
  scale_fill_manual (values =c ("#59c7eb", "#a6e1f4")) +
  geom_split_violin (trim = FALSE, alpha = 0.25, color = NA) +
  geom_boxplot (width = 0.1, outlier.shape = 21, coef = 1.5, alpha = 1, position = position_dodge (.2)) +
  labs (x = "Matured", y = "Condition (K factor)") +
  PlotTheme +
  facet_wrap (Date ~ .)
plot.118 

# weight
M103 <- glm (Weight ~ Genotype + Mature, data = SW.Fam.8.2020)
par (mfrow =c(2,2))
plot (M103)
par (mfrow =c(1,1))

Anova (M103)
r.squaredGLMM (M103)
lsmeans (M103, pairwise ~ Genotype)
lsmeans (M103, pairwise ~ Mature)

# length
M104 <- glm (Length ~ Genotype + Mature, data = SW.Fam.8.2020)
par (mfrow =c(2,2))
plot (M104)
par (mfrow =c(1,1))

Anova (M104)
r.squaredGLMM (M104)
lsmeans (M104, pairwise ~ Genotype)
lsmeans (M104, pairwise ~ Mature)

# condition
M105 <- glm (Condition ~ Genotype + Mature, data = SW.Fam.8.2020)
par (mfrow =c(2,2))
plot (M105)
par (mfrow =c(1,1))

Anova (M105)
r.squaredGLMM (M105)
lsmeans (M105, pairwise ~ Genotype)
lsmeans (M105, pairwise ~ Mature)

#### figure S15 edits - family 8 body weight ####
# edits
plot.107.edt <- plot.107 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0,.3) +
  annotate ("text", x = 1, y = .0, label = "(44) (39)", size = 5, color = "#636363") 

plot.110.edt <- plot.110 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0,2) +
  annotate ("text", x = 1, y = 0, label = "(44) (39)", size = 5, color = "#636363") 

plot.113.edt <- plot.113 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (4, 12) +
  annotate ("text", x = 1, y = 4, label = "(43) (39)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 4, label = "(1) (0)", size = 5, color = "#636363")  

plot.116.edt <- plot.116 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0, 25) +
  annotate ("text", x = 1, y = 0, label = "(0) (25)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0, label = "(43) (14)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.107.edt + plot.110.edt + plot.113.edt + plot.116.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Weight (kg)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### figure S16 edits - family 8 length ####
# edits
plot.108.edt <- plot.108 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (15,30) +
  annotate ("text", x = 1, y = 15, label = "(44) (39)", size = 5, color = "#636363") 

plot.111.edt <- plot.111 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (30,60) +
  annotate ("text", x = 1, y = 30, label = "(44) (39)", size = 5, color = "#636363") 

plot.114.edt <- plot.114 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (55, 95) +
  annotate ("text", x = 1, y = 55, label = "(43) (39)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 55, label = "(1) (0)", size = 5, color = "#636363")  

plot.117.edt <- plot.117 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (80, 120) +
  annotate ("text", x = 1, y = 80, label = "(0) (25)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 80, label = "(43) (14)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.108.edt + plot.111.edt + plot.114.edt + plot.117.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Length (cm)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))

#### figure S17 edits - family 8 condition ####
# edits
plot.109.edt <- plot.109 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (1, 1.5) +
  annotate ("text", x = 1, y = 1, label = "(44) (39)", size = 5, color = "#636363") 

plot.112.edt <- plot.112 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (1, 1.5) +
  annotate ("text", x = 1, y = 1, label = "(44) (39)", size = 5, color = "#636363") 

plot.115.edt <- plot.115 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (.9, 1.7) +
  annotate ("text", x = 1, y = .9, label = "(43) (39)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = .9, label = "(1) (0)", size = 5, color = "#636363")  

plot.118.edt <- plot.118 +
  theme (axis.text = element_text (size = 15),
         axis.title.x = element_blank (),
         axis.title.y = element_blank ()) +
  ylim (0.7, 1.7) +
  annotate ("text", x = 1, y = 0.7, label = "(0) (25)", size = 5, color = "#636363") +
  annotate ("text", x = 2, y = 0.7, label = "(43) (14)", size = 5, color = "#636363")   

grid.arrange (patchworkGrob(plot.109.edt + plot.112.edt + plot.115.edt + plot.118.edt +
                              plot_layout (guides = "collect") & 
                              theme (legend.position = "top")),
              left = text_grob ("Condition (K factor)", size = 18, rot = 90, face = "bold"),
              bottom = text_grob ("Mature", size = 18, face = "bold"))